/*--------------------------------------------------------------
	# WooCommerce
--------------------------------------------------------------*/

/**
 * General
 */

 	/* table */
 	.woocommerce table.shop_table {
 		border-radius: 0;
 	}

	/* inputs */
	.select2-container--default .select2-selection--single {
		height: auto;
		outline: none;
		border-radius: 0;
	}

	.select2-container--default .select2-selection--single .select2-selection__rendered {
		line-height: 18px;
		margin: 0;
		padding: 0;
	}

	.select2-container--default .select2-selection--single .select2-selection__arrow {
		height: 40px;
	}

	/* pagination */
	.woocommerce nav.woocommerce-pagination ul {
		border: 0;
		margin: 0;
		padding: 0;
	}
		.woocommerce nav.woocommerce-pagination ul li {
			border: 0;
		}
			.woocommerce nav.woocommerce-pagination ul li a,
			.woocommerce nav.woocommerce-pagination ul li span {
				margin: 0 3px;
				background-color: #edf4f6;
				color: #767676;
				font-size: 16px;		
				font-family: "Montserrat", sans-serif;
				line-height: 1;
				padding: 12px 17px;
				display: inline-block;
				cursor: pointer;
				text-align: center;
				text-transform: uppercase;
			}
			.woocommerce nav.woocommerce-pagination ul li a:focus, 
			.woocommerce nav.woocommerce-pagination ul li a:hover, 
			.woocommerce nav.woocommerce-pagination ul li span.current {
				background: #3db8db;
				color: #fff;
			}

	/* button */
	.woocommerce #respond input#submit.alt, 
	.woocommerce a.button.alt, 
	.woocommerce button.button.alt, 
	.woocommerce input.button.alt,
	.woocommerce ul.products li.product .button,
	.woocommerce #respond input#submit, 
	.woocommerce a.button, 
	.woocommerce button.button, 
	.woocommerce input.button {
		background: #3db8db;
		color: #fff;
		text-transform: uppercase;
		border-radius: 0;
		font-size: 12px;
		font-weight: bold;
		font-family: "Montserrat";
		padding: 12px 22px;
		margin: 0;
	}
	.woocommerce #respond input#submit.alt:hover,
	.woocommerce a.button.alt:hover,
	.woocommerce button.button.alt:hover,
	.woocommerce input.button.alt:hover {
		background: #3db8db;
	}
	.woocommerce a.button, 
	.woocommerce button.button, 
	.woocommerce input.button {
		background: #7f64b5;
	}
	.woocommerce a.button:hover, 
	.woocommerce button.button:hover, 
	.woocommerce input.button:hover {
		background: #7f64b5;
		color: #fff;
	}
	.woocommerce #respond input#submit.disabled, 
	.woocommerce #respond input#submit:disabled,
	.woocommerce #respond input#submit:disabled[disabled],
	.woocommerce a.button.disabled,
	.woocommerce a.button:disabled,
	.woocommerce a.button:disabled[disabled],
	.woocommerce button.button.disabled,
	.woocommerce button.button:disabled,
	.woocommerce button.button:disabled[disabled],
	.woocommerce input.button.disabled,
	.woocommerce input.button:disabled,
	.woocommerce input.button:disabled[disabled] {
		color: #fff;
		padding: 12px 22px;
	}

/**
 * Shop
 */

.woocommerce ul.products li.product, 
.woocommerce-page ul.products li.product {
	width: 31.49%;
	margin-right: 2.76%;
}
.woocommerce ul.products li.product.last, 
.woocommerce-page ul.products li.product.last {
	margin-right: 0;
}

	/* shop order select */
	.woocommerce .woocommerce-ordering select {		
		border: 1px solid #aaa;
	}

/* on sale */
.woocommerce span.onsale {
	background: #7f64b5;
	border-radius: 0;
	margin: 0 !important;
	top: 0;
	left: 0;
}

/* single main */

	/* single main title */
	.woocommerce div.product .product_title {
		font-size: 20px;
		margin-bottom: 10px;
	}

	/* single main rating */
	.woocommerce div.product .woocommerce-product-rating {
		margin-bottom: 10px;
	}
		.woocommerce .star-rating::before {
			color: #3db8db;
		}
		.woocommerce .star-rating span {
			color: #3db8db;
		}

	/* single main price */
	.woocommerce div.product p.price, 
	.woocommerce div.product span.price,
	.woocommerce ul.products li.product .price {
		color: inherit;
	}

	/* single main details */
	.woocommerce-product-details__short-description {
		margin-bottom: 15px;
	}

	/* single cart */
	.woocommerce div.product form.cart {
		margin-bottom: 20px;
	}

/* single tabs */
.woocommerce-tabs {
	
}

	/* single tabs nav */
	.woocommerce div.product .woocommerce-tabs ul.tabs {
		border-bottom: 1px solid #cfdfe3;
		padding: 0;
		margin-bottom: 0;
	}
	.woocommerce div.product .woocommerce-tabs ul.tabs li::before,
	.woocommerce div.product .woocommerce-tabs ul.tabs li::after {
		display: none;
	}
	.woocommerce div.product .woocommerce-tabs ul.tabs li {
		margin: 0;
		border: 0;
		padding: 0;
		background: transparent;
	}
	.woocommerce div.product .woocommerce-tabs ul.tabs::before {
		border: 0;
	}
		.woocommerce div.product .woocommerce-tabs ul.tabs li a {
			padding: 10px 20px;
			font-size: 12px;
		}

	/* single tabs content */
	.woocommerce div.product .woocommerce-tabs .panel {
		padding: 30px 0;
	}
		.woocommerce div.product .woocommerce-tabs .panel h2 {
			font-size: 16px;
			margin-bottom: 20px;
		}

/* widget posts */
.woocommerce ul.cart_list li, 
.woocommerce ul.product_list_widget li,
.woocommerce .widget_shopping_cart .cart_list li, 
.woocommerce.widget_shopping_cart .cart_list li {
	
}
	
	/* widgets post remove from cart */
	.woocommerce .widget_shopping_cart .cart_list li a.remove, 
	.woocommerce.widget_shopping_cart .cart_list li a.remove {
		background: #da4a4a;
		border-radius: 0;
		color: #fff !important;
	}

	/* widget posts title */
	.woocommerce ul.cart_list li a, 
	.woocommerce ul.product_list_widget li a {
		font-size: 14px;
	}

/* widget filter */
.woocommerce .widget_price_filter .ui-slider {
	margin: 0;
	margin-bottom: 30px;	
}
.woocommerce .widget_layered_nav_filters ul li {
	display: block;
	float: none;
}
.woocommerce .widget_layered_nav ul li.chosen a::before,
.woocommerce .widget_layered_nav_filters ul li a::before {
	border-radius: 0;
	content: '×';
	font-weight: bold;
	background: #da4a4a;
	color: #fff;
	height: 1em;
	width: 1em;
	text-align: center;
	display: inline-block;
	font-family: "Montserrat";
}

/* Cart */
body.woocommerce-cart #content {
	width: 100%;
}

	/* cart table "product name" */
	.woocommerce table.shop_table th.product-name {
		text-align: left;
	}

	/* coupon */
	.woocommerce #content table.cart td.actions .input-text, 
	.woocommerce table.cart td.actions .input-text, 
	.woocommerce-page #content table.cart td.actions .input-text, 
	.woocommerce-page table.cart td.actions .input-text {
		width: 190px;
		padding: 8px 10px;
	}

/**
 * Checkout page
 */

/* coupon wrapper */
.woocommerce form.checkout_coupon,
.woocommerce form.login, 
.woocommerce form.register {
	border: 1px solid #eee;
}
	
	/* coupon input */
	.woocommerce form.checkout_coupon .form-row-first {
		max-width: 300px;
	}

	/* coupon button */
	.woocommerce form.checkout_coupon .form-row-last {
		float: left;
	}

	/* login input */
	.woocommerce form.login .form-row-last {
		float: none;
	}

	/* login button */
	.woocommerce form.login input[type="submit"] {
		margin-right: 10px;
	}

	/* lost password */
	.woocommerce form.login .lost_password {
		margin: 10px 0 0 0;
	}

/* checkout form wrapper */
#customer_details {
	margin-bottom: 30px;
}
	
	/* checkout form headings */
	#customer_details h3,
	#order_review_heading {
		font-size: 18px;
	}

	#add_payment_method #payment ul.payment_methods, 
	.woocommerce-cart #payment ul.payment_methods, 
	.woocommerce-checkout #payment ul.payment_methods {
		border-bottom: 1px solid #eee;
	}

	#add_payment_method #payment div.payment_box, 
	.woocommerce-cart #payment div.payment_box, 
	.woocommerce-checkout #payment div.payment_box {
		background: #f5f5f5;
	}

		#add_payment_method #payment div.payment_box::before, 
		.woocommerce-cart #payment div.payment_box::before, 
		.woocommerce-checkout #payment div.payment_box::before {
			display: none;
		}

	/* payment method */
	#add_payment_method #payment, 
	.woocommerce-cart #payment, 
	.woocommerce-checkout #payment {
		background: #fff;
		border: 1px solid #eee;
		border-radius: 0;
	}


/**
 * # Responsive
 */

/*--------------------------------------------------------------
	## Tablets
--------------------------------------------------------------*/
@media only screen and ( min-width: 768px ) and ( max-width: 1023px ) {

	/* shop */

		/* shop product */
		.woocommerce ul.products li.product, 
		.woocommerce-page ul.products li.product {
			width: 48.62%;
		}

		/* shop product "last" */
		.woocommerce ul.products li.product.last, 
		.woocommerce-page ul.products li.product.last {
			margin-right: 2.76%;
		}

		/* shop product "first" */
		.woocommerce ul.products li.first, 
		.woocommerce-page ul.products li.first {
			clear: none;
		}

		/* shop product every 2nd */
		.woocommerce ul.products li.product:nth-child(2n), 
		.woocommerce-page ul.products li.product:nth-child(2n), 
		.woocommerce-page[class*=columns-] ul.products li.product:nth-child(2n), 
		.woocommerce[class*=columns-] ul.products li.product:nth-child(2n) {
			margin-right: 0;
		}

}

/*--------------------------------------------------------------
	## Phones ( landscape + portrait )
--------------------------------------------------------------*/
@media only screen and ( max-width: 767px ) {

	/* single */

		/* single thumb */
		.woocommerce #content div.product div.images, 
		.woocommerce div.product div.images, 
		.woocommerce-page #content div.product div.images, 
		.woocommerce-page div.product div.images {
			width: 100%;
		}

		/* single content */
		.woocommerce #content div.product div.summary, 
		.woocommerce div.product div.summary, 
		.woocommerce-page #content div.product div.summary, 
		.woocommerce-page div.product div.summary {
			width: 100%;
			padding: 20px;
		}

	/* shop */

		/* shop filter */
		.woocommerce .woocommerce-ordering, 
		.woocommerce-page .woocommerce-ordering {
			float: none;
		}

		/* shop product */
		.woocommerce ul.products li.product, 
		.woocommerce-page ul.products li.product {
			width: 100%;
			margin-right: 0;
		}

	/* cart */

		/* cart cross sell product */
		.woocommerce .cart-collaterals .cross-sells ul.products li, 
		.woocommerce-page .cart-collaterals .cross-sells ul.products li {
			width: 100%;
			display: none;
		}

		/* cart cross sell product first */
		.woocommerce .cart-collaterals .cross-sells ul.products li:first-child, 
		.woocommerce-page .cart-collaterals .cross-sells ul.products li:first-child {
			display: block;
		}

	/* order received */
	body.woocommerce-order-received ul.order_details {
		padding: 0;
	}

		/* order received details */
		.woocommerce ul.order_details li {
			float: none;
			border: 0;
			margin-bottom: 15px;
		}
		.woocommerce ul.order_details li:last-child {
			margin-bottom: 0;
		}

		

}