.meridian-one-importer {
	position: relative;
	margin: 16px 0;
	padding: 25px;
	border: 1px solid #e5e5e5;
	border-left: 4px solid #46b450;
	-webkit-box-shadow: 0 1px 1px rgba(0,0,0,.04);
	box-shadow: 0 1px 1px rgba(0,0,0,.04);
	background: #fff;
	font-size: 13px;
	line-height: 2.1em;
}

	.meridian-one-importer-inner {
		overflow: hidden;
	}

		.meridian-one-importer h2 {
			font-weight: bold;
			margin: 0;
			margin-bottom: 20px;
		}

		.meridian-one-importer-info {
			margin-bottom: 20px;
		}

		.meridian-one-importer-all {
			
		}

		.meridian-one-importer-row {
			border: 1px solid #e5e5e5;
			-webkit-box-shadow: 0 1px 1px rgba(0,0,0,.04);
			box-shadow: 0 1px 1px rgba(0,0,0,.04);
			padding: 20px;
			margin-bottom: 20px;
			float: left;
			margin-right: 3%;
			box-sizing: border-box;
			display: none;
			font-size: 12px;
			text-transform: uppercase;
		}

			.meridian-one-importer-title {
				font-weight: bolder;
				font-size: 18px;
				margin-bottom: 15px;
			}

			.meridian-one-importer-descr {
				margin-bottom: 15px;
			}

			.meridian-one-importer-button {
				margin-bottom: 15px;
			}

			.meridian-one-importer-progress {

			}

				.meridian-one-importer-progress-item {
					display: none;
				}

					.meridian-one-importer-progress-item span,
					.meridian-one-importer-progress-item strong {
						display: none;
					}

					.meridian-one-importer-progress-item strong {
						color: #289559;
					}

