<?php
/**
 * Template for the header
 *
 * @package Meridian One
 * @since 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>

	<?php if ( function_exists( 'wp_body_open' ) ) wp_body_open(); ?>

	<div id="page" class="site">

		<header id="header">

			<div id="header-inner" class="clearfix">

				<?php get_template_part( 'template-parts/header/logo' ); ?>

				<?php get_template_part( 'template-parts/header/navigation' ); ?>

			</div><!-- #header-inner -->

		</header><!-- #header -->

		<?php get_template_part( 'template-parts/header/breadcrumbs' ); ?>

		<div id="main" class="site-content">

			<?php if ( ! is_page_template( 'template-home.php' ) ) : ?>
				<div class="wrapper clearfix">
			<?php endif; ?>
