<?php
	
	// get author ID	
	$author_id = false;	
	if ( get_the_author_meta( 'ID' ) )
		$author_id = get_the_author_meta( 'ID' );

?>

<?php if ( $author_id && get_the_author_meta( 'description', $author_id ) ) : ?>

	<div class="about-author clearfix">
						
		<div class="about-author-sidebar">
			<div class="about-author-avatar">
				<?php echo get_avatar( $author_id , 120 ); ?>
			</div><!-- .about-author-avatar -->
		</div><!-- .about-author-sidebar -->

		<div class="about-author-main">

			<h4 class="about-author-name"><?php the_author_posts_link(); ?></h4>

			<div class="about-author-bio">
				<?php echo get_the_author_meta( 'description', $author_id ); ?>
			</div><!-- .about-author-bio -->

			<div class="about-author-posts-link">
				<a href="<?php echo esc_url( get_author_posts_url( $author_id ) ); ?>"><?php esc_html_e( 'View all posts by author', 'meridian-one' ); ?></a>
			</div><!-- .about-author-posts-link -->

		</div><!-- .about-author-main -->

	</div><!-- .about-author -->

<?php endif; ?>