<?php

	$title = false;
	$subtitle = false;
	$content = false;

	if ( meridian_one_get_theme_option( 'footer_subscribe_title' ) ) {
		$title = meridian_one_get_theme_option( 'footer_subscribe_title' );
	}

	if ( meridian_one_get_theme_option( 'footer_subscribe_subtitle' ) ) {
		$subtitle = meridian_one_get_theme_option( 'footer_subscribe_subtitle' );
	}

	if ( meridian_one_get_theme_option( 'footer_subscribe_content' ) ) {
		$content = meridian_one_get_theme_option( 'footer_subscribe_content' );
	}

?>
<div class="footer-subscribe">

	<div class="wrapper clearfix">

		<?php if ( $title || $subtitle ) : ?>
			<div class="footer-subscribe-content col col-8">
				<?php if ( $title ) : ?>
					<h4 class="footer-subscribe-title"><?php echo esc_html( $title ); ?></h4>
				<?php endif; ?>
				<?php if ( $subtitle ) : ?>
					<div class="footer-subscribe-subtitle"><?php echo esc_html( $subtitle ); ?></div>
				<?php endif; ?>
			</div><!-- .footer-subscribe-content -->
		<?php endif; ?>

		<?php if ( $content ) : ?>
			<div class="footer-subscribe-form col col-4 col-last">
				<?php echo do_shortcode( esc_html( $content ) ); ?>
			</div><!-- .footer-subscribe-form -->
		<?php endif; ?>

	</div><!-- .wrapper -->

</div><!-- .footer-subscribe -->