<?php
/**
 * Template Name: Home
 *
 * @package Meridian One
 * @since 1.0
 */

get_header(); ?>

	<div id="content" role="main">

		<?php if ( meridian_one_get_theme_option( 'home_slider_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/slider' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_features_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/features' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_about_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/about' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_tour_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/tour' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_services_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/services' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_process_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/process' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_testimonials_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/testimonials' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_clients_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/clients' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_team_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/team' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_blog_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/blog' ); ?>
		<?php if ( meridian_one_get_theme_option( 'home_contact_section_enabled' ) == 1 ) get_template_part( 'template-parts/home/contact' ); ?>

	</div><!-- #content -->

<?php get_footer();
