/*!
Theme Name: AgencyX
Theme URI: https://wpthemespace.com/product/agencyx/
Author: Noor Alam
Author URI: https://wpthemespace.com/
Version: 1.0.1
Tested up to: 5.9
Requires PHP: 5.6
Description: Agencyx Digital Agency & modern WordPress theme. Agencyx theme designed for every truly modern digital studio, design studio, branding or creative agency and agency portfolio websites. It features a responsive layout, full Elementor Page Builder compatibility and lots of flexible options that make it easy to customize to your needs. It's perfect for portfolio, shop, seo, agency and all other professionals. Agency X is also a creative WordPress theme. It is not only a unique agency theme, but also a multi-purpose theme that can be used for a wide range of websites such as portfolio, personal blog, business, photography, online store, etc.
License: GNU General Public License v2 or later
License URI: http://opensource.org/licenses/gpl-2.0.php 
Text Domain: agencyx
Tags: two-columns, blog, education, right-sidebar, custom-background, custom-colors, custom-menu, custom-logo, editor-style, featured-images, full-width-template, sticky-post, theme-options, threaded-comments, translation-ready

This theme, like WordPress, is licensed under the GPL.
Use it to make something cool, have fun, and share what you've learned.

agencyx is based on Underscores https://underscores.me/, (C) 2012-2020 Automattic, Inc.
Underscores is distributed under the terms of the GNU GPL v2 or later.

Normalizing styles have been helped along thanks to the fine work of
Nicolas Gallagher and Jonathan Neal https://necolas.github.io/normalize.css/
*/
