/* Medium Layout: 1280px. */
@media only screen and (min-width: 992px) and (max-width: 1200px) {
}

/* Tablet Layout: 768px. */
@media only screen and (min-width: 768px) and (max-width: 991px) {
}

/* Mobile Layout: 320px. */
@media only screen and (max-width: 991px) {
  nav#site-navigation {
    display: none;
  }
  .pxms1-logo {
    flex: 0 0 100%;
  }
  .ax-hstyle1.has-aghome {
    color: var(--black);
    position: inherit;
    text-align: center;
  }
  /* Mobile Menu style*/

  .mobile-menu-bar {
    background: #333;
    display: block;
  }
  .mobile-menu-bar button {
    display: flex;
    justify-content: flex-end;
    margin-left: auto;
  }
  nav#mobile-navigation {
    position: relative;
  }
  nav ul.wsm-menu {
    box-shadow: 0px 5px 42px -6px rgb(92 91 92);
    padding: 20px;
    margin-bottom: 10px;
    background: var(---light-body);
    position: absolute;
    left: auto;
    right: 0;
    top: 80px;
    z-index: 99999;
    visibility: hidden;
    opacity: 0;
    transition: 0.5s;
  }
  nav.menu-active ul.wsm-menu {
    top: 40px;
    visibility: visible;
    opacity: 1;
  }

  ul.wsm-menu {
    margin: 0;
    padding: 0;
  }

  ul.wsm-menu li a {
    padding: 7px 10px;
    text-decoration: none;
    border-bottom: 1px solid #fff;
    display: block;
  }

  .mobile-navigation ul {
    list-style: none;
  }
  .menu-item-has-children {
    display: flex;
    flex-flow: row wrap;
  }
  .menu-item-has-children > a {
    width: 80%;
    min-width: 250px;
  }

  .menu-item-has-children .sub-menu {
    display: block;
    width: 100%;
  }
  span.mclose {
    display: none;
  }
  .menu-item-has-children > i {
    padding: 10px 15px;
    margin-left: auto;
  }
  ul#wsm-menu ul.sub-menu {
    visibility: hidden;
    max-height: 0;
    height: auto;
    opacity: 0;
    transition: 0.5s;
  }
  ul#wsm-menu .menu-item-has-children.clicked > ul.sub-menu,
  ul#wsm-menu .menu-item-has-children.focus > ul.sub-menu {
    max-height: 1000px;
    visibility: visible;
    opacity: 1;
    height: auto;
  }
  h1 {
    font-size: 35px;
  }
  h1.page-title {
    font-size: 20px;
  }
  h2 {
    font-size: 28px;
  }
  .aghome .ax-home-title h1 {
    font-size: 4rem;
  }
  .aghome .ax-home-dres p {
    font-size: 15px;
    letter-spacing: 0;
  }
}

/* Wide Mobile Layout: 480px. */
@media only screen and (min-width: 480px) and (max-width: 767px) {
  h1 {
    font-size: 35px;
  }
  h1.page-title {
    font-size: 24px;
  }
  h2 {
    font-size: 30px;
  }
}
/* Wide Mobile Layout: 480px. */
@media only screen and (max-width: 479px) {
  .header-search-form {
    right: 0;
  }
}
