<?php
/**
 * Template part for displaying breadcrumbs
 *
 * @package Meridian One
 * @since 1.0
 */
?>
<?php if ( ! is_home() && ! is_front_page() && ! is_page_template( 'template-home.php' ) ) : ?>
	<?php if ( function_exists('yoast_breadcrumb') ) : ?>
		<div id="tagline">
			<div class="wrapper">
				<?php yoast_breadcrumb( '<div id="breadcrumbs">', '</div>' ); ?>
			</div><!-- .wrapper -->
		</div><!-- #tagline -->
	<?php endif; ?>
<?php endif; ?>