<?php if ( is_active_sidebar( 'sidebar-2' ) ) : ?>
	<div id="footer-widgets">
		<div class="wrapper clearfix">
			<?php dynamic_sidebar( 'sidebar-2' ); ?>
		</div><!-- .wrapper -->
	</div><!-- #footer-widgets -->
<?php endif; ?>