<?php
/**
 * Custom customizer control for upsell
 *
 * @package Meridian One
 * @since 1.0
 */

if ( class_exists( 'WP_Customize_Control' ) ) :

	class WP_Customize_Meridian_One_Upsell_Control extends WP_Customize_Control {

		public $type = 'meridian_one_upsell';
 
		public function render_content() {
		?>
			<div class="meridian-one-customizer-upsell">
				<p><?php esc_html_e( 'For more features such as:', 'meridian-one' ); ?></p>
				<ul>
					<li><?php esc_html_e( 'Beautiful restyle of WooCommerce', 'meridian-one' ); ?></li>
					<li><?php esc_html_e( 'More homepage sections', 'meridian-one' ); ?></li>
					<li><?php esc_html_e( 'Ability to reorder homepage sections', 'meridian-one' ); ?></li>
					<li><?php esc_html_e( 'Styling options', 'meridian-one' ); ?></li>
					<li><?php esc_html_e( 'Premium support', 'meridian-one' ); ?></li>
					<li><?php esc_html_e( 'and more&hellip;', 'meridian-one' ); ?></li>
				</ul>
				<p><a href="https://meridianthemes.net/themes/meridian-one-plus/" target="_blank" class="button button-primary button-large"><?php esc_html_e( 'Check out Meridian One Plus', 'meridian-one' ); ?></a></p>
			</div><!-- .meridian-one-customizer-upsell -->
		<?php

		}

	}

endif;