<?php
/**
 * The template part for displaying the clients section on homepage
 *
 * @package Meridian One
 * @since 1.0
 */
?>
<div id="clients" class="section section-clients">

	<div class="wrapper">

		<div class="section-clients-main">

			<?php if ( is_active_sidebar( 'sidebar-home-clients' ) ) : ?>
				<div class="section-clients-items clearfix">					
					<?php dynamic_sidebar( 'sidebar-home-clients' ); ?>					
				</div><!-- .section-clients-items -->
			<?php endif; ?>

		</div><!-- .section-clients-main -->

	</div><!-- .wrapper -->

</div><!-- .section-clients -->