<?php
/**
 * The template part for displaying content on a single page
 *
 * @package Meridian One
 * @since 1.0
 */
?>
<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>

	<?php if ( has_post_thumbnail() ) : ?>
		<div class="page-thumb">
			<?php the_post_thumbnail( 'meridian-one-posts-listing' ); ?>
		</div><!-- .page-thumb -->
	<?php endif; ?>

	<div class="page-main">

		<h1 class="page-title"><?php the_title(); ?></h1>

		<?php the_content(); ?>

		<div class="clear"></div>
		<?php edit_post_link( esc_html__( 'Edit', 'meridian-one' ), '<span class="edit-link">', '</span>' ); ?>

	</div><!-- .page-main -->

</article><!-- #post-## -->
