<?php
/**
 * Template for displaying 404 page
 *
 * @package Meridian One
 * @since 1.0
 */

get_header(); ?>

	<div id="content" <?php meridian_one_content_class(); ?> role="main">

		<h1 class="page-title"><?php esc_html_e( 'Sorry, Nothing Found!', 'meridian-one' ); ?></h1>
		<p><?php esc_html_e( 'The page you were looking for could not be found. Maybe try the search form below.', 'meridian-one' ); ?></p>
		<?php get_search_form(); ?>

	</div><!-- #content -->

	<?php get_sidebar(); ?>

<?php get_footer();
