/*
	Theme Name: Meridian One
	Theme URI: https://meridianthemes.net/themes/meridian-one/
	Author: MeridianThemes
	Author URI: https://meridianthemes.net
	Description: Meridian One is a well-coded WordPress one page theme, perfect for portfolio, business, digital agency, photography, freelancers, blog, ecommerce shop, and product showcase. Some of the key features include WPML, retina-ready, WooCommerce compatible, SEO friendly, and more.
	Requires PHP: 5.2.4
	Tested up to: 5.8
	Version: 1.0.5.1
	License: GNU General Public License v2 or later
	License URI: http://www.gnu.org/licenses/gpl-2.0.html
	Tags: one-column, two-columns, right-sidebar, custom-menu, featured-images, full-width-template, sticky-post, footer-widgets, theme-options, threaded-comments, translation-ready, e-commerce, blog
	Text Domain: meridian-one
*/

/*--------------------------------------------------------------

	= Table Of Contents =

	# Normalize
	# General
		## Typography
		## Elements
		## Forms
		## Links
		## Screen Reader
	# WordPress Specific
		## Captions
		## Galleries
	# Floats and Clearing
	# Columns System
	# Header
		## Logo
		## Navigation
		## Mobile Nav
		## Tagline
	# Main
		## Content
		## Blog Posts Listing		
		## Blog Post Single
		## About Author
		## Comments
		## Sidebar
	# Homepage
		## Slider
		## Features
		## About
		## Tour
		## Services
		## Process
		## Testimonials
		## Clients
		## Team
		## Blog
		## Contact
	# Widgets
	# Footer Subscribe
	# Footer
		## Footer Widgets
		## Footer Bottom
	# Responsive
		## Medium Monitors
		## Smaller Monitors
		## Tablets
		## Phones ( landscape + portrait )
		## Phones ( landscape )
		## Phones ( portrait )

--------------------------------------------------------------*/

/*--------------------------------------------------------------
	# Normalize
--------------------------------------------------------------*/

img,legend{border:0}legend,td,th{padding:0}html{font-family:sans-serif;-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%}body{margin:0}article,aside,details,figcaption,figure,footer,header,main,menu,nav,section,summary{display:block}audio,canvas,progress,video{display:inline-block;vertical-align:baseline}audio:not([controls]){display:none;height:0}[hidden],template{display:none}a{background-color:transparent}a:active,a:hover{outline:0}abbr[title]{border-bottom:1px dotted}b,optgroup,strong{font-weight:700}dfn{font-style:italic}h1{font-size:2em;margin:.67em 0}mark{background:#ff0;color:#000}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sup{top:-.5em}sub{bottom:-.25em}svg:not(:root){overflow:hidden}figure{margin:0;}hr{box-sizing:content-box;height:0}pre,textarea{overflow:auto}code,kbd,pre,samp{font-family:monospace,monospace;font-size:1em}button,input,optgroup,select,textarea{color:inherit;font:inherit;margin:0}button{overflow:visible}button,select{text-transform:none}button,html input[type=button],input[type=reset],input[type=submit]{-webkit-appearance:button;cursor:pointer}button[disabled],html input[disabled]{cursor:default}button::-moz-focus-inner,input::-moz-focus-inner{border:0;padding:0}input{line-height:normal}input[type=checkbox],input[type=radio]{box-sizing:border-box;padding:0}input[type=number]::-webkit-inner-spin-button,input[type=number]::-webkit-outer-spin-button{height:auto}input[type=search]{-webkit-appearance:textfield;box-sizing:content-box}input[type=search]::-webkit-search-cancel-button,input[type=search]::-webkit-search-decoration{-webkit-appearance:none}fieldset{border:1px solid silver;margin:0 2px;padding:.35em .625em .75em}table{border-collapse:collapse;border-spacing:0}
html { box-sizing: border-box; } *, *:before, *:after { box-sizing: inherit; }
.page-content .wp-smiley,.entry-content .wp-smiley,.comment-content .wp-smiley {border: none;margin-bottom: 0;margin-top: 0;padding: 0;}embed,iframe,object {max-width: 100%;}.widget select { max-width: 100%; }

/*--------------------------------------------------------------
	# General
--------------------------------------------------------------*/

/*--------------------------------------------------------------
	## Typography
--------------------------------------------------------------*/

body,
button,
input,
select,
textarea {
	color: #6b6b6b;
	font-size: 15px;
	font-weight: 400;
	font-family: "Lora", serif;
	line-height: 1.8;
}

h1, h2, h3, h4, h5, h6 {
	clear: both;
	margin: 0;
	padding: 0;
	margin-bottom: 25px;
	color: #343338;
	line-height: 1.45;
	font-weight: normal;
	font-family: "Montserrat", sans-serif;
}

h1 {
	font-size: 33px;
}

h2 {
	font-size: 25px;
}

h3 {
	font-size: 23px;
}

h4 {
	font-size: 21px;
}

h5 {
	font-size: 19px;
}

h6 {
	font-size: 17px;
}

p {
	margin: 0;
	margin-bottom: 25px;
}

p:last-child {
	margin: 0;
}

dfn, cite, em, i {
	font-style: italic;
}

blockquote {
	color: #767676;
	font-size: 17px;
	font-style: italic;
	line-height: 1.8;
	padding: 30px;
	border-left: 2px solid #3db8db;
	background: #edf4f6;
	margin-left: 0;
	margin-right: 0;
}

	blockquote p:last-child {
		margin: 0;
	}

address {
	margin-bottom: 25px
}

pre {
	background: #eee;
	font-family: "Courier 10 Pitch", Courier, monospace;
	font-size: 15px;
	line-height: 1.6;
	margin-bottom: 25px;
	max-width: 100%;
	overflow: auto;
	padding: 1.6em;
}

code, kbd, tt, var {
	font-family: Monaco, Consolas, "Andale Mono", "DejaVu Sans Mono", monospace;
	font-size: 15px;
}

abbr, acronym {
	border-bottom: 1px dotted #666;
	cursor: help;
}

mark, ins {
	background: #fff9c0;
	text-decoration: none;
}

big {
	font-size: 125%;
}

small {
	font-size: 75%;
}

/*--------------------------------------------------------------
	## Elements
--------------------------------------------------------------*/

body {
	background: #f4f8f9;
	padding-top: 0px;
}

blockquote:before,
blockquote:after,
q:before,
q:after {
	content: "";
}

blockquote,
q {
	quotes: "" "";
}

hr {
	background-color: #ccc;
	border: 0;
	height: 1px;
	margin-bottom: 25px;
}

ul,
ol {
	margin: 0;
	margin-bottom: 25px;
	padding: 0 0 0 15px;
}

ul {
	list-style: disc;
}

ol {
	list-style: decimal;
}

li > ul,
li > ol {
	margin-bottom: 0;
	margin-left: 0;
}

dt {
	font-weight: bold;
}

dd {
	margin: 0 1.5em 1.5em;
}

img {
	height: auto;
	max-width: 100%;
}

table {
	margin-bottom: 25px;
	width: 100%;
	line-height: 1;
}

table thead {
	background: #2c2c2e;
	color: #fff;
	text-align: left;
}

table td,
table th {
	padding: 10px 14px;
	text-align: left;
}

table tbody th {
	background: #2c2c2e;
	color: #fff;
}

table tbody th a {
	color: inherit;
}

.text-align-center {
	text-align: center;
}

.text-align-left {
	text-align: left;
}

.text-align-right {
	text-align: right;
}

.position-relative {
	position: relative;
}

.position-absolute {
	position: absolute;
}

.hidden {
	display: none !important;
}

/*--------------------------------------------------------------
	## Forms
--------------------------------------------------------------*/

button,
input[type="button"],
input[type="reset"],
input[type="submit"] {
	background: #3db8db;
	border: 0;
	color: #fff;
	font-size: 12px;
	font-weight: 700;
	font-family: "Montserrat", sans-serif;
	line-height: 1;
	padding: 12px 15px;
	text-transform: uppercase;
}

button:hover,
input[type="button"]:hover,
input[type="reset"]:hover,
input[type="submit"]:hover {
	
}

button:focus,
input[type="button"]:focus,
input[type="reset"]:focus,
input[type="submit"]:focus,
button:active,
input[type="button"]:active,
input[type="reset"]:active,
input[type="submit"]:active {

}

select,
input[type="text"],
input[type="email"],
input[type="url"],
input[type="password"],
input[type="search"],
input[type="tel"],
.select2-container--default .select2-selection--single,
textarea {
	background: #edf4f6;
    border: 0;
	color: #4d4d4d;
	font-size: 15px;
	font-weight: 500;
	font-family: inherit;
	line-height: 1.4;
	padding: 9px 15px;
	max-width: 100%;
}

select,
input[type="text"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
input[type="search"]:focus,
input[type="tel"]:focus,
textarea:focus {
	color: #4d4d4d;
	outline: none;
}

textarea {
	width: 100%;
}

/*--------------------------------------------------------------
	## Links
--------------------------------------------------------------*/

a {
	text-decoration: none;
	color: #3db8db;
}

/*--------------------------------------------------------------
	## Screen Reader
--------------------------------------------------------------*/

.screen-reader-text {
	clip: rect(1px, 1px, 1px, 1px);
	position: absolute !important;
	height: 1px;
	width: 1px;
	overflow: hidden;
}

.screen-reader-text:focus {
	background-color: #f1f1f1;
	border-radius: 3px;
	box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
	clip: auto !important;
	color: #21759b;
	display: block;
	font-size: 14px;
	font-size: 0.875rem;
	font-weight: bold;
	height: auto;
	left: 5px;
	line-height: normal;
	padding: 15px 23px 14px;
	text-decoration: none;
	top: 5px;
	width: auto;
	z-index: 100000; /* Above WP toolbar. */
}

/* Do not show the outline on the skip link target. */
#content[tabindex="-1"]:focus {
	outline: 0;
}

/*--------------------------------------------------------------
	# WordPress Specific
--------------------------------------------------------------*/

.sticky {
	border: 2px solid #3db8db;
}

.bypostauthor {

}

.alignleft {
	display: inline;
	float: left;
	margin-right: 1.5em;
}

.alignright {
	display: inline;
	float: right;
	margin-left: 1.5em;
}

.aligncenter {
	clear: both;
	display: block;
	margin-left: auto;
	margin-right: auto;
}

/*--------------------------------------------------------------
	## Captions
--------------------------------------------------------------*/

.wp-caption {
	margin: 0;
	margin-top: 20px;
	margin-bottom: 20px;
	max-width: 100%;
}

.wp-caption.alignleft {
	margin-right: 20px;
}

.wp-caption.alignright {
	margin-left: 20px;
}

.wp-caption img[class*="wp-image-"] {
	display: block;
	margin-left: auto;
	margin-right: auto;
	-moz-box-shadow: 0px 0px 5px 0px rgba( 0, 0, 0, 0.15 );
	-webkit-box-shadow: 0px 0px 5px 0px rgba( 0, 0, 0, 0.15 );
	box-shadow: 0px 0px 5px 0px rgba( 0, 0, 0, 0.15 );
}

.wp-caption .wp-caption-text {
	font-size: 14px;
	line-height: 1.7;
	margin: 0;
	padding: 0 10%;
	font-family: "Lato", sans-serif;
	margin-top: 20px;
}

.wp-caption-text {
	text-align: center;
}

/*--------------------------------------------------------------
	## Galleries
--------------------------------------------------------------*/

.gallery {
	margin-bottom: 1.5em;
}

.gallery-item {
	display: inline-block;
	text-align: center;
	vertical-align: top;
	width: 100%;
	padding: 5px;
}

.gallery-item a,
.gallery-item img {
	display: block;
}

.gallery-columns-2 .gallery-item {
	max-width: 50%;
}

.gallery-columns-3 .gallery-item {
	max-width: 33.33%;
}

.gallery-columns-4 .gallery-item {
	max-width: 25%;
}

.gallery-columns-5 .gallery-item {
	max-width: 20%;
}

.gallery-columns-6 .gallery-item {
	max-width: 16.66%;
}

.gallery-columns-7 .gallery-item {
	max-width: 14.28%;
}

.gallery-columns-8 .gallery-item {
	max-width: 12.5%;
}

.gallery-columns-9 .gallery-item {
	max-width: 11.11%;
}

.gallery-caption {
	display: block;
}

/*--------------------------------------------------------------
	# Floats and Clearing
--------------------------------------------------------------*/

.float-left {
	float: left;
}

.float-right {
	float: right;
}

.float-none {
	float: none;
}

.clearfix:before, .clearfix:after { content: " "; display: table; }
.clearfix:after { clear: both; }
.clearfix { *zoom: 1; }

.clear { clear: both; }

/*--------------------------------------------------------------
	# Columns System
--------------------------------------------------------------*/

.wrapper {
	max-width: 1170px;
	margin: 0 auto;
}

.col {
	display: block;
	float: left;
	margin-right: 2.76%;
}

body.rtl .col {
	float: right;
	margin-left: 2.76%;
	margin-right: 0;
}

.col-1 { width: 5.803%; }
.col-2 { width: 14.36%; }
.col-3 { width: 22.93%; }
.col-4 { width: 31.49%; }
.col-5 { width: 40.05%; }
.col-6 { width: 48.62%; }
.col-7 { width: 57.18%; }
.col-8 { width: 65.74%; }
.col-9 { width: 74.31%; }
.col-10 { width: 82.87%; }
.col-11 { width: 91.43%; }
.col-12 { width: 100%; }

.col-last {
	margin-right: 0;
}

body.rtl .col-last {
	margin-left: 0;
}

.col-first {
	clear: both;
}

.no-col-spacing .col { margin: 0; }
.no-col-spacing .col-1 { width: 8.33333%; }
.no-col-spacing .col-2 { width: 16.66666%; }
.no-col-spacing .col-3 { width: 25%; }
.no-col-spacing .col-4 { width: 33.33333%; }
.no-col-spacing .col-5 { width: 41.66666%; }
.no-col-spacing .col-6 { width: 50%; }
.no-col-spacing .col-7 { width: 58.33333%; }
.no-col-spacing .col-8 { width: 66.66666%; }
.no-col-spacing .col-9 { width: 75%; }
.no-col-spacing .col-10 { width: 83.33333%; }
.no-col-spacing .col-11 { width: 91.66666%; }
.no-col-spacing .col-12 { width: 100%; }

.owl-carousel .col {
	width: auto;
	margin-right: 0;
}

/*--------------------------------------------------------------
	# Header
--------------------------------------------------------------*/

#header {
	background: #2c2c2e;
}

body.page-template-template-home-php {
	padding-top: 85px;
}

body.page-template-template-home-php #header {
	position: fixed;
	left: 0;
	right: 0;
	top: 0;
	z-index: 9999;
}

body.page-template-template-home-php.admin-bar #header {
	top: 32px;
}

	#header-inner {
		padding: 0 50px;
	}

/*--------------------------------------------------------------
	## Logo
--------------------------------------------------------------*/

#logo {
	padding: 29px 0;
	position: relative;
	line-height: 0;
	float: left;
}

	#logo .site-title {
		color: #fff;
		line-height: 1;
		font-size: 18px;
		margin: 0;
		text-transform: uppercase;
		font-family: "Montserrat";
		font-weight: bold;
	}

		#logo .site-title a {
			color: inherit;
		}

	#logo .site-description {
		font-size: 12px;
		line-height: 1;
		margin-top: 5px;
	}

	#logo a,
	#logo img {
		display: inline-block;
	}

/*--------------------------------------------------------------
	## Navigation
--------------------------------------------------------------*/

#navigation {
	z-index: 99998;
	position: relative;
	width: auto;
	float: right;
}

	#navigation ul,
	#navigation li {
		list-style-type: none;
		margin: 0;
		padding: 0;
	}

		/* Top level item */
		#navigation .menu > li {
			display: inline-block;
			position: relative;
			z-index: 99998;
			margin-left: 50px;
		}

		/* Top level first item */
		#navigation .menu > li:first-child {
			margin-left: 0;
		}

			/* Top level chevron */
			#navigation .menu a .fa {
				display: inline-block;
				color: rgb(165, 165, 165);
				font-size: 7px;
				margin-left: 10px;
				vertical-align: middle;
			}


			/* Top level item anchor */
			#navigation .menu > li > a {
				display: inline-block;
				text-decoration: none;
				vertical-align: middle;
				color: #b7bcc4;
				font-size: 13px;
				font-weight: 700;
				font-family: "Montserrat", sans-serif;
				line-height: 1;
				letter-spacing: 1px;
				padding: 36px 0;
				text-transform: uppercase;
			}

			/* Top level item anchor hover */
			#navigation .menu > li > a:hover {
				color: #fff;
			}

			/* Top level item anchor current */
			#navigation .menu > li.current-menu-item > a {
				color: #fff;
			}

	/* Submenu */
	#navigation .menu ul {
		background: #2c2c2e;
		visibility: hidden;
		opacity: 0;
		position: absolute;
		top: 100%;
		left: -25px; /* same as horrizontal padding on #navigation .menu ul li */
		text-align: left;
		padding: 10px 0;
		-webkit-transition: .5s opacity;
		-moz-transition: .5s opacity;
		transition: .5s opacity;
	}

		/* Submenu item */
		#navigation .menu ul li {
			position: relative;
			display: block;
			white-space: nowrap;
			margin: 0;
			padding: 0 25px; /* same as left on #navigation .menu ul */
		}

			/* Submenu item anchor */
			#navigation .menu ul li a {
				display: block;
				text-decoration: none;
				color: #686868;
				font-size: 12px;
				font-weight: 700;
				font-family: "Montserrat", sans-serif;
				letter-spacing: 1px;
				text-transform: uppercase;
				line-height: 1.25;
				border-bottom: 1px solid #404040;
				padding-top: 11px;
				padding-bottom: 11px;
				text-transform: uppercase;
			}

			/* Submenu last item anchor */
			#navigation .menu ul li:last-child a {
				border-bottom: 0;
			}

			/* Submenu item anchor hover */
			#navigation .menu ul li a:hover {
				 color: #fff;
			}

			/* Submenu item anchor hover */
			#navigation .menu ul li.current-menu-item > a {
				color: #fff;
			}

		/* Second lvl submenu */
		#navigation .menu ul ul {
			left: 100%;
			margin-left: 0;
			top: -11px; /* upper level padding + border */
		}

		/* Show submenu on hover */
		#navigation .menu li:hover > ul {
			visibility: visible;
			opacity: 1;
		}

/*--------------------------------------------------------------
	## Mobile Nav
--------------------------------------------------------------*/

#mobile-navigation {
	display: none;
	text-align: center;
	margin-top: 34px;
	color: #fff;
	font-size: 12px;
	font-weight: bold;
	font-family: "Lato", sans-serif;
	line-height: 1;
	letter-spacing: 1px;
	padding: 0;
	text-transform: uppercase;
	float: right;
}

	#mobile-navigation .fa {
		margin-right: 10px;
	}

	.header-mobile-nav-hook {
		cursor: pointer;
	}

	#mobile-navigation .fa {
		cursor: pointer;
	}

	#mobile-navigation-menu {
		display: none;
		background: #111;
		text-align: left;
		position: absolute;
		left: 0;
		right: 0;
		margin-top: 47px;
	}

	#mobile-navigation.active #mobile-navigation-menu {
		display: block;
	}

	#mobile-navigation ul,
	#mobile-navigation li {
		list-style-type: none;
		margin: 0;
		padding: 0;
	}

		/* Top level item */
		#mobile-navigation .menu li {
			display: block;
			position: relative;
			border-bottom: 1px solid rgba( 255, 255, 255, 0.1 );
		}

		#mobile-navigation .menu li:last-child {
			border-bottom: 0;
		}

			/* Top level chevron */
			#mobile-navigation .menu a .fa {
				display: inline-block;
				color: #fff;
				font-size: 7px;
				margin-left: 10px;
				vertical-align: middle;
			}

			/* Top level item anchor */
			#mobile-navigation .menu li > a {
				display: block;
				text-decoration: none;
				color: #fff;
				font-size: 12px;
				font-weight: bold;
				font-family: "Lato", serif;
				line-height: 42px;
				padding: 0;
			}

			/* Top level item anchor hover */
			#mobile-navigation .menu li > a:hover {
				color: #fff;
			}

			/* Top level item anchor current */
			#mobile-navigation .menu li.current-menu-item > a {
				color: #fff;				
			}

	/* Submenu */
	#mobile-navigation .menu ul {	
		border-top: 1px solid rgba( 255, 255, 255, 0.1 );
		padding-left: 10px;
		display: none;
	}

	/* submenu expanded */
	#mobile-navigation li.expand > ul {
		display: block;
	}

		/* Submenu item */
		#mobile-navigation .menu ul li {	
			border-bottom-width: 1px;
			position: relative;
		}

			/* submenu indicator */
			#mobile-navigation li .fa {
				display: block;
				position: absolute;
				right: 0;
				top: 0;
				line-height: 44px;
				width: 30px;
				height: 44px;
				text-align: center;
				cursor: pointer;
				color: #fff;
			}

			#mobile-navigation li ul .fa {
				height: 32px;
				line-height: 32px;
			}

			/* submenu indicator active */
			#mobile-navigation li.expand > .fa:before {
				content: "\f068";
			}

			/* Submenu anchor */
			#mobile-navigation .menu ul li > a {	
				font-size: 12px;
				line-height: 32px;
			}


/*--------------------------------------------------------------
	## Tagline
--------------------------------------------------------------*/

#tagline {
	background: #fff;
	padding: 50px 0;
}

	#breadcrumbs {
		font-family: "Montserrat";
		text-transform: uppercase;
		font-size: 12px;
		font-weight: 500;
	}

		#breadcrumbs .sep {
			margin: 0 5px;
		}

/*--------------------------------------------------------------
	# Main
--------------------------------------------------------------*/

#main {
	padding: 50px 0;
}

body.page-template-template-home-php #main {
	padding: 0;
}

/*--------------------------------------------------------------
	## Content
--------------------------------------------------------------*/

#content {

}

body.error404 #content {
	background: #fff;
	padding: 40px;
}

.section-heading {
	margin-bottom: 27px;
	font-size: 0;
	line-height: 0;
}

	.section-heading h2 {
		display: inline-block;
		margin: 0;
		padding: 0;
		color: #1c1c1c;
		font-size: 11px;
		font-weight: 700;
		font-family: "Lato", sans-serif;
		letter-spacing: 2px;
		line-height: 1.55;
		text-transform: uppercase;
	}

	.section-heading a {
		display: inline-block;
		border-left: 1px solid #d4d4d4;
		color: #3db8db;
		font-size: 11px;
		font-weight: 700;
		font-family: Lato;
		letter-spacing: 2px;
		line-height: 1.55;
		padding-left: 15px;
		margin-left: 15px;
		text-transform: uppercase;
	}

/*--------------------------------------------------------------
	## Blog Posts Listing
--------------------------------------------------------------*/

.blog-posts-listing .post,
.blog-posts-listing .page {
	margin-bottom: 50px;
}

.blog-posts-listing .post.sticky {
	
}

	.blog-posts-listing .edit-link {
		margin-left: 5px;
	}

	.edit-link {
		color: #232323;
		font-size: 11px;
		font-weight: 700;
		font-family: "Lato", sans-serif;
		line-height: 1;
		margin-bottom: 20px;
	}

		.edit-link a {
			color: inherit;
			text-decoration: underline;
		}

	/* thumb */
	.blog-post-thumb {
		font-size: 0;
		line-height: 0;
	}

	.blog-post-thumb-audio {
		padding: 30px;
		background: #edf4f6;
	}

		.blog-post-thumb a,
		.blog-post-thumb img {
			display: inline-block;
			max-width: 100%;
		}

	/* main */
	.blog-post-main,
	.page-main {
		background: #fff;
		padding: 40px;
	}

		/* meta */
		.blog-post-meta {

		}

		/* title */
		.blog-post-title {
			font-size: 21px;
			font-weight: bold;
			text-transform: uppercase;
			margin: 0;
			margin-bottom: 20px;
		}

			.blog-post-title a {
				color: inherit;
			}

		/* meta */
		.blog-post-meta {
			border-bottom: 1px solid #cfdfe3;
			padding-bottom: 15px;
			margin-bottom: 15px;
			color: #aeacb2;
			font-size: 12px;
		}

			.post-meta-separator {
				margin: 0 15px;
			}

			.blog-post-meta a {
				font-weight: bold;
			}

		/* excerpt */

		/* button */

		.blog-post-read-more {
			
		}

			.blog-post-read-more a {
				display: inline-block;
				background: #3db8db;
				color: #fff;
				font-size: 12px;
				font-weight: 700;
				font-family: "Montserrat", sans-serif;
				line-height: 1;
				padding: 12px 15px;
				text-transform: uppercase;
			}

			.blog-post-read-more a:hover {
				
			}

/* quote */

.blog-posts-listing .post.format-quote {

}

	.blog-post-title .fa {
		margin-left: 15px;
	}

	.blog-post-quote-icon {
		display: block;
		float: left;
		width: 55px;
		height: 55px;
		line-height: 55px;
		text-align: center;
		background: #3db8db;
		border-radius: 50%;
		margin-right: 30px;
		color: #fff;
		font-size: 16px;
	}

	.blog-post-quote-content {
		overflow: hidden;
	}

		.blog-post-quote-content blockquote {
			margin: 0;
			padding: 0;
			background: transparent;
			border: 0;
		}

		.blog-post-quote-content blockquote cite {
			font-family: "Montserrat";
			font-size: 13px;
			font-weight: bold;
			text-transform: uppercase;
			color: #343338;
			font-style: normal;
			margin-top: 10px;
			display: block;
		}

		.blog-post-quote-content blockquote cite:before {
			content: "- ";
		}

			.blog-post-quote-content blockquote cite a {
				color: inherit;
			}
/* other */

.blog-post-single-tags {
	margin-top: 25px;
}

.blog-post-single-pagination,
.pagination,
#infinite-handle {
	margin-top: 50px;
	text-align: center;
}

.infinite-scroll .pagination {
	display: none;
}

.infinite-loader {
	margin-top: 50px;
}

	.infinite-loader .spinner {
		margin-left: 48%;
	}

.comment-navigation {
	margin-bottom: 20px;
}

.blog-post-single-pagination {
	text-align: left;
}

	.comment-navigation .nav-previous,
	.comment-navigation .nav-next {
		display: inline-block;
		margin-right: 10px;
	}

	.comment-navigation a,
	.blog-post-single-pagination a,
	.blog-post-single-pagination p > span,
	.pagination a,
	.pagination span.current,
	#infinite-handle span {
		margin: 0 3px;
		background-color: #edf4f6;
		color: #767676;
		font-size: 16px;		
		font-family: "Montserrat", sans-serif;
		line-height: 1;
		padding: 12px 17px;
		display: inline-block;
		cursor: pointer;
		text-align: center;
		text-transform: uppercase;
	}

	#infinite-handle span {
		padding-top: 0;
		padding-bottom: 0;
	}

	.comment-navigation a {
		margin: 0;
	}

	.blog-post-single-pagination p > span,
	.pagination span.current {
		background: #3db8db;
		color: #fff;
	}

/*--------------------------------------------------------------
	## Blog Post Single
--------------------------------------------------------------*/

/* thumb */
.blog-post-single-thumb,
.page-thumb {
	
}

	.blog-post-single-thumb img {
		display: block;
	}

/* main */
.blog-post-single-main {
	background: #fff;
	padding: 40px;
}

	/* title */
	.blog-post-single-title,
	.page-title {
		font-size: 21px;
		font-weight: bold;
		text-transform: uppercase;
		margin: 0;
		margin-bottom: 20px;
	}

	/* meta */
	.blog-post-single-meta {
		border-bottom: 1px solid #cfdfe3;
		padding-bottom: 15px;
		margin-bottom: 25px;
		color: #aeacb2;
		font-size: 12px;
	}

		.post-meta-separator {
			margin: 0 15px;
		}

		.blog-post-single-meta a {
			font-weight: bold;
		}

	.blog-post-single-meta-social {
		float: right;
		line-height: 1.3;
		padding: 10px 0;
	}

		.blog-post-single-meta-social .blog-post-share,
		.blog-post-single-meta-social .blog-post-share a {
			line-height: inherit;
		}

		.blog-post-single-meta-social .blog-post-share {
			padding: 0;
		}

body.single-post #content .navigation {
	background: #fff;
	padding: 40px;
	position: relative;
	overflow: hidden;
	margin-top: 40px;
}

	body.single-post #content .navigation .nav-previous,
	body.single-post #content .nav-next {
		max-width: 50%;
		float: left;
		position: relative;
	}

		.nav-next {
			text-align: right;
		}

		.nav-previous a,
		.nav-next a {
			display: block;			
			font-size: 14px;
			font-weight: 700;
			font-family: "Montserrat", sans-serif;
			line-height: 1.5;
			cursor: pointer;
			text-transform: uppercase;
			color: inherit;
		}

		.blog-post-single-nav-button {
			display: block;
			margin-bottom: 10px;
			color: #3db8db;
		}

			.nav-previous .blog-post-single-nav-button .fa {
				margin-right: 10px;
				display: inline-block;
			}

		.blog-post-single-nav-prev-title,
		.blog-post-single-nav-next-title {
			font-size: 14px;
			font-family: "Montserrat";
			line-height: 1.4;
			color: inherit;
			text-transform: uppercase;
		}

	body.single-post #content .navigation .nav-next {
		float: right;
		text-align: right;
	}

		.nav-next .blog-post-single-nav-button .fa {
			margin-left: 10px;
			display: inline-block;
		}

/*--------------------------------------------------------------
	## About Author
--------------------------------------------------------------*/

.about-author {
	background: #fff;
	padding: 40px;
	margin-top: 40px;
}
	
	.about-author-sidebar {
		float: left;
		margin-right: 30px;
	}

		.about-author-avatar {
			
		}

			.about-author-avatar img {
				
			}

	.about-author-main {
		overflow: hidden;
	}

		.about-author-name {
			font-size: 17px;
			font-family: "Montserrat";
			font-weight: bold;
			margin-bottom: 15px;
			text-transform: uppercase;
		}

			.about-author-name a {
				color: inherit;
			}

		.about-author-bio {
			margin-bottom: 15px;
		}

		.about-author-posts-link {

		}

			.about-author-posts-link a {
				font-family: "Montserrat";
				font-size: 12px;
				text-transform: uppercase;
				font-weight: 600;
			}

/*--------------------------------------------------------------
	## Comments
--------------------------------------------------------------*/

.comments-title {
	font-size: 17px;
	font-weight: bold;
	text-transform: uppercase;
}

.comments-area {
	margin-top: 50px;
}

.comments-area .comment-list,
.comments-area .children,
.comments-area .comment {
	margin: 0;
	padding: 0;
	list-style-type: none;
}

.comment-list > li.pingback {
	padding: 5px 0;
	border-bottom: 1px solid #ddd;
	font-size: 80%;
}

.pingback + .comment {
	padding-top: 37px;
}

.comments-area ol.comment-list {
	background: #fff;
	padding: 40px;
}

.comment {

}

	.comment-body {
		border-radius: 3px;
		margin-bottom: 50px;
	}

	.pingback .comment-body {
		margin-bottom: 0;
	}

	ol.comment-list > li:last-child > .comment-body {
		margin-bottom: 0;
	}

		.comment-meta {
			overflow: hidden;
		}

			.comment-meta .comment-author {
				float: left;
				color: #343338;
				font-size: 15px;
				font-weight: bold;
				font-family: "Montserrat", sans-serif;
				text-transform: uppercase;
				margin-right: 10px;
			}

				.comment-meta .avatar {
					border-radius: 50%;
					vertical-align: middle;
					margin-right: 10px;
				}

				.comment-meta .comment-author .says {
					display: none;
				}

			.comment-meta .comment-metadata {
				float: left;
				font-size: 11px;
				color: #aeacb2;
				line-height: 32px;
			}

				.comment-meta .comment-metadata a {
					color: inherit;
				}

				.comment-meta .comment-metadata .edit-link {
					margin-left: 10px;
				}

		.comment-content {
			margin-top: 15px;
		}

		.comment .reply {
			margin-top: 15px;
		}

			.comment .reply a {
				display: inline-block;
				background: #3db8db;
				color: #fff;
				font-size: 12px;
				font-weight: 700;
				font-family: "Montserrat", sans-serif;
				line-height: 1;
				padding: 12px 15px;
				text-transform: uppercase;
				color: #fff;
			}

	.comment .children {
		margin-left: 70px;
	}

	.comments-no-comments {
		margin-bottom: 20px;
	}

.comment-respond {
	margin-top: 40px;
	background-color: #fff;
	padding: 40px;
}

	.comment-reply-title {
		font-size: 17px;
		font-weight: bold;
		text-transform: uppercase;
	}

	.comment-respond .logged-in-as,
	.comment-notes {
		font-size: 13px;
		color: #8d8d8d;
	}

		.comment-form-comment {

		}

		.comment-form-name,
		.comment-form-email,
		.comment-form-website {

		}

			.comment-respond label {
				font-size: 11px;
				font-weight: bold;
				font-family: "Montserrat";
				line-height: 1;
				margin-bottom: 20px;
				text-transform: uppercase;
				display: block;
			}

			.comment-respond input[type="text"],
			.comment-respond input[type="email"],
			.comment-respond input[type="url"] {
				width: 400px;
			}

			.comment-respond input[type="text"],
			.comment-respond input[type="email"],
			.comment-respond input[type="url"],
			.comment-respond textarea {
				background: #f4f8f9;
			}

			.comment-respond textarea {
				height: 140px;
			}

		.comment-respond .form-submit {
			clear: both;
			margin-bottom: 0;
		}

/*--------------------------------------------------------------
	## Sidebar
--------------------------------------------------------------*/

#sidebar {

}

	#sidebar .widget {
		margin-bottom: 30px;
	}

	#sidebar .widget:last-child {
		margin-bottom: 0;
	}

		#sidebar .widget-title {
			margin: 0;
			padding: 0;
			color: #343338;
			font-size: 16px;
			font-weight: 700;
			font-family: "Montserrat", sans-serif;
			line-height: 1.36;
			margin-bottom: 25px;
			text-transform: uppercase;
		}

.search-form input[type="submit"],
form[role="search"] input[type="submit"] {
	padding: 13px 15px;
}

/*--------------------------------------------------------------
	# Homepage
--------------------------------------------------------------*/

.section {
	padding: 90px 0;
}
	
	.section-header {
		text-align: center;
		margin-bottom: 90px;
	}

		.section-title {
			margin: 0;
			color: #e3e3e3;
			font-weight: bold;
			font-size: 14px;
			text-transform: uppercase;
			letter-spacing: 2px;
			margin-bottom: 5px;
		}

		.section-subtitle {
			margin: 0;
			font-weight: bold;
			font-size: 21px;
			text-transform: uppercase;
			margin-bottom: 30px;
		}

		.section-description {
			color: #7b7a7f;
			line-height: 1.8;
			font-size: 18px;
			max-width: 600px;
			margin: 0 auto;
		}

		.section-header-left {
			float: left;
			text-align: left;
			margin-right: 80px;
		}

		.section-header-right {
			overflow: hidden;
			text-align: left;
			padding-left: 80px;
			border-left: 1px solid #e8e8e8;
		}

		.section-header-right.has-button {

		}

			.section-header-right .section-description {
				max-width: none;
				margin: 0;
				font-size: 15px;
			}

			.section-header-right.has-button .section-description {
				overflow: hidden;
			}

			.section-header-button {
				float: right;
				display: block;
				line-height: 60px;
				font-family: "Montserrat";
				font-weight: bold;
				font-size: 14px;
				color: #7f64b5;
				text-transform: uppercase;
				border: 1px solid #7f64b5;
				padding: 0 20px;
				width: 240px;
				max-width: 100%;
				text-align: center;
				margin-left: 70px;
			}

/*--------------------------------------------------------------
	## Slider
--------------------------------------------------------------*/

#slider {
	position: relative;
}

	.slider-inner {
		position: relative;
	}

	.slide {
		position: relative;
	}

		.slide img {
			display: block;
			position: relative;
			width: 100%;
		}

		.slide-info {
			position: absolute;
			top: 50%;
			left: 0;
			right: 0;
		}

			.slide-info-inner {
				max-width: 48%;
			}

				.slide-info-title {
					color: #fff;
					font-size: 60px;
					line-height: 1;
					text-transform: uppercase;
					font-weight: bold;
					margin-bottom: 20px;
				}

				.slide-info-content {
					color: rgba( 255, 255, 255, 0.6 );
					margin-bottom: 35px;
				}

				.slide-info-button {
					display: inline-block;
					line-height: 50px;
					font-family: "Montserrat";
					font-weight: bold;
					font-size: 14px;
					background: #7f64b5;
					color: #fff;
					text-transform: uppercase;
					padding: 0 20px;
					width: 180px;
					max-width: 100%;
					text-align: center;
				}

					.slide-info-button span {
						margin-left: 10px;
					}

	.slider-nav {
		position: absolute;
		top: 50%;
		margin-top: -50px;
		width: 40px;
		line-height: 100px;
		height: 100px;
		background: rgba( 0, 0, 0, 0.5 );
		color: #fff;
		text-align: center;
		font-size: 16px;
		z-index: 100;
		cursor: pointer;
	}

	.slider-nav-prev {
		left: 0;
	}

	.slider-nav-next {
		right: 0;
	}

/*--------------------------------------------------------------
	## Features
--------------------------------------------------------------*/

.section-features {
	background: #fff;
}

	.section-features .section-header {
		margin-bottom: 50px;
	}

	.section-features-main-wrap {
		
	}

	.section-features-main-wrap:before {
		content: " ";
		position: relative;
		width: 2px;
		height: 90px;
		display: block;
		margin: 0 auto;
		background: #7f64b5;
	}

		.section-features-main {

		}

		.section-features-main:before {
			content: " ";
			position: relative;
			width: 12px;
			height: 12px;
			border-radius: 50%;
			display: block;
			margin: 0 auto;
			background: #7f64b5;
		}

			.section-features-main-inner {
				padding-top: 60px;
			} 

				.section-features-items {
					padding-top: 50px;
				}

					.section-features-items .widget:nth-child(2n) {
						margin-right: 0;
					}

					.section-features-item {
						margin-bottom: 90px;
					}

						.section-features-item-icon {
							font-size: 25px;
							line-height: 1;
							color: #7f64b5;
							display: block;
							margin-bottom: 25px;
						}

						.section-features-item-title {
							font-size: 15px;
							font-weight: bold;
							text-transform: uppercase;
							margin-bottom: 20px;
						}

						.section-features-item-description {

						}

		.section-features-image {
			position: relative;
		}

			.section-features-image img {
				display: block;
			}

			.section-features-image-caption {
				position: absolute;
				left: -30px;
				bottom: 30px;
				right: 120px;
				padding: 30px;
				background: #3db8db;
			}

				.section-features-image-caption-title {
					color: #fff;
					text-transform: uppercase;
					font-size: 15px;
					font-weight: bold;
					margin-bottom: 15px;
				}

				.section-features-image-caption-description {
					color: rgba( 255, 255, 255, 0.7 );
				}

/*--------------------------------------------------------------
	## About
--------------------------------------------------------------*/

.section-about {

}

	.section-about-main {

	}

		.section-about-items {
			padding: 0 60px;
		}

			.section-about-items .widget {
				margin-top: 40px;
			}

			.section-about-items .widget:nth-child(-n+3) {
				margin-top: 0;
			}

			.section-about-items .widget:nth-child(3n) {
				margin-right: 0;
			}

			.section-about-items .widget:nth-child(2) {
				box-shadow: 0px 0px 80px 0px rgba(57,67,69,0.22);
			}

			.section-about-item {
				text-align: center;
				background: #fff;
				padding: 100px 90px;
			}

				.section-about-item-icon {
					width: 120px;
					height: 120px;
					line-height: 120px;
					font-size: 30px;
					border-radius: 50%;
					background: #7f64b5;
					display: inline-block;
					color: #fff;
					margin-bottom: 35px;
				}

				.section-about-item-title {
					font-size: 15px;
					font-weight: bold;
					margin-bottom: 25px;
					text-transform: uppercase;
				}

				.section-about-item-description {

				}

/*--------------------------------------------------------------
	## Tour
--------------------------------------------------------------*/

.section-tour {
	background-size: cover;
	text-align: center;
	padding: 0;
}

	.section-tour-inner {
		background: rgba( 55, 96, 108, 0.5 );
		padding: 200px 0;
	}

		.section-tour-play {

		}

			.section-tour-play span {
				display: inline-block;
				background: #3db8db;
				color: #fff;
				line-height: 60px;
				height: 60px;
				width: 60px;
				border-radius: 50%;
				text-align: center;
				cursor: pointer;
			}

		.section-tour-title {
			margin-top: 25px;
			font-family: "Montserrat";
			font-size: 70px;
			font-weight: bold;
			line-height: 1;
			color: rgba( 255, 255, 255, 0.2 );
			text-transform: uppercase;
		}

/*--------------------------------------------------------------
	## Services
--------------------------------------------------------------*/

.section-services {
	background: #fff;
	padding-bottom: 0;
}

	.section-services-main {

	}

		.section-services-tabs-nav {
			text-align: center;
			margin-bottom: 50px;
		}

			.section-services-tabs-nav-item {
				display: inline-block;
				margin: 0 45px;
				margin-bottom: 50px;
			}

			.section-services-tabs-nav-item:not(.active) {
				color: inherit;
			}

				.section-services-tabs-nav-item-icon {
					display: inline-block;
					font-size: 25px;
					line-height: 1;
					color: #7f64b5;
					display: block;
					margin-bottom: 15px;
				}

				.section-services-tabs-nav-item.active .section-services-tabs-nav-item-icon {
					color: #3db8db;
				}

				.section-services-tabs-nav-item-title {
					display: block;
					margin-top: 10px;
					font-size: 14px;
					font-weight: bold;
					font-family: "Montserrat";
					text-transform: uppercase;
				}

		.section-services-tabs-content {
			
		}

			.section-services-tabs-content-item {
				display: none;
				position: relative;
			}

			.section-services-tabs-content-item.active {
				display: block;
			}

				.section-services-tabs-content-image {
					font-size: 0;
					line-height: 0;
					text-align: center;
				}

					.section-services-tabs-content-image img {
						display: inline-block;
					}

				.section-services-tabs-content-info {
					position: absolute;
					left: 0;
					top: 100px;
				}

				.section-services-tab-no-image .section-services-tabs-content-info {
					position: relative;
					left: auto;
					top: auto !important;
					padding-bottom: 40px;
				}

					.section-services-tabs-content-info-icon {
						display: none;
					}

					.section-services-tabs-content-info-title {
						display: inline-block;
						background: #3db8db;
						font-size: 34px;
						font-weight: bold;
						line-height: 1;
						color: #fff;
						text-transform: uppercase;
						margin: 0;
						padding: 20px;
					}

					.section-services-tabs-content-info-description {
						padding: 30px;
						max-width: 400px;
						background: #fff;
						box-shadow: 0px 0px 40px 7px rgba(57,67,69,0.1);
					}

					.section-services-tab-no-image .section-services-tabs-content-info-description {
						max-width: 100%;
					}

/*--------------------------------------------------------------
	## Process
--------------------------------------------------------------*/

.section-process {
	background: #f4f8f9;
	padding: 130px 0;
}

	.section-process-items {

	}

		.section-process-items .widget {
			margin-top: 50px;
		}

		.section-process-items .widget:nth-child(-n+3) {
			margin-top: 0;
		}

		.section-process-items .widget:nth-child(3n) {
			margin-right: 0;
		}

		.section-process-item {

		}

			.section-process-item-number {
				display: block;
				color: #343338;
				font-size: 30px;
				line-height: 1;
				font-family: "Montserrat";
				font-weight: bold;
				margin-bottom: 20px;
			}

			.section-process-item-title {
				font-size: 14px;
				font-weight: bold;
				text-transform: uppercase;
				margin-bottom: 20px;
			}

			.section-process-item-description {

			}

	.section-process-button {
		text-align: center;
		margin-top: 60px;
	}

		.section-process-button a {
			display: inline-block;
			border: 4px solid #343338;
			color: #343338;
			line-height: 50px;
			padding: 0 30px;
			font-weight: bold;
			font-family: "Montserrat";
			text-transform: uppercase;
		}

/*--------------------------------------------------------------
	## Testimonials
--------------------------------------------------------------*/

.section-testimonials {
	background: #7f64b5;
}

	.section-testimonials .section-header {
		margin-bottom: 35px;
	}

		.section-testimonials .section-title {
			color: #4b3478;
		}

		.section-testimonials .section-subtitle {
			color: #fff;
			margin-bottom: 0;
		}

	.section-testimonials-customer-count {
		text-align: center;
	}

	.section-testimonials-customer-count:after {
		content: " ";
		height: 30px;
		width: 1px;
		position: relative;
		background: #886ebd;
		margin: 0 auto;
		display: block;
	}

		.section-testimonials-customer-count-inner {
			display: inline-block;
			background: #755aaa;
			padding: 30px 50px;
			font-family: "Montserrat";
			color: #fff;
			text-transform: uppercase;
		}

			.section-testimonials-customer-count span {
				display: inline-block;
				font-weight: 100;
				font-size: 62px;
				line-height: 1;
				margin-right: 40px;
				letter-spacing: -1px;
			}

			.section-testimonials-customer-count strong {
				display: inline-block;
				font-size: 21px;
				font-weight: bold;
				text-align: left;
				line-height: 1.43;
			}

	.section-testimonials-items {
		border-top: 1px solid #886ebd;
		padding: 0 80px;
	}

		.section-testimonials-item {
			padding: 0 35px;
		}

			.section-testimonials-item-thumb {
				width: 80px;
				height: 80px;
				float: left;
				margin-right: 30px;
			}

			.section-testimonials-item-thumb:before {
				content: " ";
				height: 60px;
				width: 1px;
				position: relative;
				background: #886ebd;
				margin: 0 auto;
				display: block;
			}

				.section-testimonials-item-thumb img {
					display: block;
					border-radius: 50%;
				}

			.section-testimonials-item-main {
				overflow: hidden;
			}

				.section-testimonials-item-content {
					margin-top: 60px;
					margin-bottom: 45px;
					color: #d8c5ff;
				}

				.section-testimonials-item-title {
					text-transform: uppercase;
					display: block;
					font-size: 14px;
					font-weight: bold;
					font-family: "Montserrat";
					color: #fff;
				}

				.section-testimonials-item-extra {
					display: block;
					color: #d8c5ff;
				}

/*--------------------------------------------------------------
	## Clients
--------------------------------------------------------------*/

.section-clients {
	background: #fff;
	text-align: center;
}

	.section-clients-items .widget {
		display: inline-block;
		margin: 0 40px;
	}

/*--------------------------------------------------------------
	## Team
--------------------------------------------------------------*/

.section-team {
	background: #fff;
}

	.section-team .section-header {
		
	}

	.section-team-items {

	}

		.section-team-items .widget {
			margin-top: 40px;
		}

		.section-team-items .widget:nth-child(-n+4) {
			margin-top: 0;
		}

		.section-team-items.section-team-items-cols-4 .widget:nth-child(4n) {
			margin-right: 0;
		}

		.section-team-items.section-team-items-cols-3 .widget:nth-child(3n) {
			margin-right: 0;
		}

		.section-team-items.section-team-items-cols-2 .widget:nth-child(2n) {
			margin-right: 0;
		}

		.section-team-items.section-team-items-cols-1 .widget {
			margin-right: 0;
		}

		.section-team-item {
			text-align: center;
		}

			.section-team-item-thumb {
				margin-bottom: 25px;
			}

				.section-team-item-thumb a,
				.section-team-item-thumb img {
					display: block;
				}

			.section-team-item-title {
				font-size: 14px;
				font-weight: bold;
				font-family: "Montserrat";
				color: #343338;
				text-transform: uppercase;
				margin-bottom: 5px;
			}

			.section-team-item-extra {

			}

/*--------------------------------------------------------------
	## Blog
--------------------------------------------------------------*/

.section-blog {
	
}

	.section-blog-info {

	}

		.section-blog-filters {
			margin: 0;
			padding: 0;
			list-style-type: none;
			margin-bottom: 35px;
		}

			.section-blog-filters li {
				margin-bottom: 20px;
			}

			.section-blog-filters li:last-child {
				margin-bottom: 0;
			}

				.section-blog-filters li a {
					display: inline-block;
					color: inherit;
					font-size: 12px;
					line-height: 1;
					padding: 3px;
					font-family: "Montserrat";
					text-transform: uppercase;
				}

				.section-blog-filters li.active a {
					background: #fff;
				}

		.section-blog-button {
			display: inline-block;
			line-height: 50px;
			font-family: "Montserrat";
			font-weight: bold;
			font-size: 14px;
			background: #3db8db;
			color: #fff;
			text-transform: uppercase;
			padding: 0 20px;
			width: 180px;
			max-width: 100%;
			text-align: center;
		}

	.section-blog-items {

	}

	.section-blog-items.section-blog-filtering {
		opacity: 0.5;
	}

		.section-blog-item {

		}

			.section-blog-item-thumb {
				margin-bottom: 25px;
				position: relative;
			}

				.section-blog-item-thumb img {
					display: block;
				}

				.section-blog-item-thumb-cats {
					position: absolute;
					top: 35px;
					left: -15px;
				}

					.section-blog-item-thumb-cats a {
						display: inline-block;
						background: #fff;
						color: inherit;
						font-family: "Montserrat";
						font-size: 12px;
						line-height: 1;
						font-weight: bold;
						text-transform: uppercase;
						padding: 5px 15px;
						margin-bottom: 5px;
						margin-right: 5px;
					}

			.section-blog-item-title {
				font-size: 14px;
				font-weight: bold;
				font-family: "Montserrat";
				color: #343338;
				text-transform: uppercase;
				margin-bottom: 5px;
			}

				.section-blog-item-title a {
					color: inherit;
				}

			.section-blog-item-date {

			}

/*--------------------------------------------------------------
	## Contact
--------------------------------------------------------------*/

.section-contact {
	
}

	.section-contact-main {
		background: #2f363c;
	}

		.section-contact-map {

		}

			.section-contact-map iframe {
				width: 100%;
				display: block;
			}

		.section-contact-form {
			padding: 80px;
		}

			.section-contact-form .section-title {
				color: #a7a7a7;
			}

			.section-contact-form .section-subtitle {
				color: #fff;
				margin-bottom: 50px;
			}

			.section-contact-form .wpcf7-form-control-wrap {
				display: block;
				margin-bottom: 30px;
			}

				.section-contact-form input[type="text"], 
				.section-contact-form input[type="email"],
				.section-contact-form input[type="url"],
				.section-contact-form input[type="password"],
				.section-contact-form input[type="search"],
				.section-contact-form textarea {
					background: transparent;
					border-bottom: 1px solid #59636b;
					padding: 10px 0;
					margin: 0;
					color: #93979a;
				}

				.section-contact-form textarea {
					height: 100px;
				}

				.section-contact-form input[type="submit"] {
					line-height: 50px;
					font-size: 14px;
					padding: 0 20px;
					width: 180px;
					max-width: 100%;
					text-align: center;
				}

	.section-contact-extra {
		margin-top: 90px;
	}

		.section-contact-extra .widget {
			margin-top: 40px;
		}

		.section-contact-extra .widget:nth-child(-n+3) {
			margin-top: 0;
		}

		.section-contact-extra .widget:nth-child(3n) {
			margin-right: 0;
		}

		.section-contact-extra-item {

		}

			.section-contact-extra-item-icon {
				display: block;
				float: left;
				width: 70px;
				height: 70px;
				line-height: 70px;
				border-radius: 50%;
				border: 1px solid #7f64b5;
				margin-right: 30px;
				text-align: center;
				font-size: 20px;
				color: #7f64b5;
			}

			.section-contact-extra-item-main {
				overflow: hidden;
			}

				.section-contact-extra-item-main strong {
					display: block;
					font-weight: bold;
					font-family: "Montserrat";
					text-transform: uppercase;
					color: #343338;
					font-size: 14px;
					line-height: 1;
					margin-bottom: 15px;
					margin-top: 15px;
				}

				.section-contact-extra-item-main span {
					display: block;
				}

/*--------------------------------------------------------------
	# Widgets
--------------------------------------------------------------*/

.widget {

}

	#wp-calendar caption {
		text-align: left;
		margin-bottom: 15px;
	}

/*--------------------------------------------------------------
	# Footer Subscribe
--------------------------------------------------------------*/

.footer-subscribe {
	background: #3db8db;
	color: #d0f5ff;
	padding: 90px 0;
}

	.footer-subscribe-content {

	}

		.footer-subscribe-title {
			font-size: 18px;
			font-weight: bold;
			color: #fff;
			text-transform: uppercase;
			margin-bottom: 10px;
		}

		.footer-subscribe-subtitle {

		}

	.footer-subscribe-form {
		text-align: right;
		position: relative;
	}

		.footer-subscribe-form input[type="text"],
		.footer-subscribe-form input[type="email"] {
			background: transparent;
			border-bottom: 1px solid #379ebc;
			padding: 10px 0;
			width: 100%;
			color: #d1f5ff;
		}

		.footer-subscribe-form input[type="text"]::-webkit-input-placeholder { /* Chrome/Opera/Safari */
			color: #d1f5ff;	
		}
		.footer-subscribe-form input[type="text"]::-moz-placeholder { /* Firefox 19+ */
			color: #d1f5ff;
		}
		.footer-subscribe-form input[type="text"]:-ms-input-placeholder { /* IE 10+ */
			color: #d1f5ff;
		}

		.footer-subscribe-form input[type="submit"] {
			background: #379ebc;
			position: absolute;
			right: 0;
			top: 0;
			bottom: 1px;
		}

/*--------------------------------------------------------------
	# Footer
--------------------------------------------------------------*/

#footer {
	background: #fff;
}

/*--------------------------------------------------------------
	## Footer Widgets
--------------------------------------------------------------*/

#footer-widgets {
	padding: 75px 0;
	text-align: left;
}

	#footer-widgets a {
		color: #3db8db;
		font-weight: bold;
	}

	#footer-widgets ul {
		list-style-type: none;
		padding-left: 0;
	}

		#footer-widgets li {
			margin-bottom: 15px;
		}

	#footer-widgets .widget {
		margin-top: 50px;
	}

	#footer-widgets .widget:nth-child(-n+4) {
		margin-top: 0;
	}

	#footer-widgets .widget:nth-child(4n) {
		margin-right: 0;
	}

		#footer-widgets .widget-title {			
			font-size: 16px;
			font-weight: bold;
			font-family: "Montserrat", sans-serif;
			line-height: 1.25;
			margin-bottom: 30px;
			text-transform: uppercase;
		}			

/*--------------------------------------------------------------
	## Footer Bottom
--------------------------------------------------------------*/

#footer-bottom {
	font-size: 13px;
}

	#footer-bottom .wrapper {
		border-top: 1px solid #eaeaea;
		padding: 25px 0;
	}

	/**
	 * Footer Copyright
	 */

	#footer-copyright {
		float: left;
	}

	/**
	 * Footer Social
	 */

	#footer-social {
		float: right;
	}

		#footer-social a {
			color: #858585;
			margin-left: 10px;
			padding: 0 5px;
		}

		#footer-social a:first-child {
			margin-left: 0;
		}

/*--------------------------------------------------------------
	# Responsive
--------------------------------------------------------------*/

/*--------------------------------------------------------------
	## Medium Monitors
--------------------------------------------------------------*/

@media only screen and ( min-width: 1281px ) and ( max-width: 1400px )  {

	/**
	 * Homepage
	 */

	/* about */
	body .section-about-item {
		padding: 70px 50px;
	}
	body .section-about-item-icon {
		width: 80px;
		line-height: 80px;
		height: 80px;
	}

	/* tour */
	body .section-tour-inner {
		padding: 150px 0;
	}

}

/*--------------------------------------------------------------
	## Smaller Monitors
--------------------------------------------------------------*/

@media only screen and ( min-width: 1024px ) and ( max-width: 1280px )  {

	body .wrapper {
		max-width: 940px;
	}

	/* Navigation */

	body #navigation .menu > li {
		margin-left: 18px;
	}

	/**
	 * Homepage
	 */

	/* slider */
	body .slide-info-inner {
		max-width: 60%;
	}

	/* about */
	body .section-about-item {
		padding: 50px 30px;
	}
	body .section-about-item-icon {
		width: 80px;
		line-height: 80px;
		height: 80px;
	}

	/* tour */
	body .section-tour-inner {
		padding: 100px 0;
	}

	/* testimonials */
	body .section-testimonials-item-thumb {
		float: none;
	}
	body .section-testimonials-item-thumb {
		margin-bottom: 20px;
	}

	/* team */
	body .section-header-right.has-button .section-description {
		display: none;
	}
	body .section-header-right {
		border: 0;
	}

}

/*--------------------------------------------------------------
	## Tablets
--------------------------------------------------------------*/

@media only screen and ( min-width: 768px ) and ( max-width: 1023px ) {

	body .wrapper {
		max-width: 748px;
	}

	/* Navigation */

	body #navigation {
		display: none;
	}
	body #mobile-navigation {
		display: block;
	}

	/**
	 * Homepage
	 */

	/* slider */
	body .slide-info-inner {
		max-width: 60%;
	}
		body .slide-info-title {
			font-size: 48px;
		}

	/* features */
	body .section-features-items {
		padding-top: 0;
	}
	body .section-features-image-caption {
		position: relative;
		left: auto;
		right: auto;
		top: auto;
		bottom: auto;
	}

	/* about */
	body .section-about-item {
		padding: 50px 30px;
	}
	body .section-about-item-icon {
		width: 80px;
		line-height: 80px;
		height: 80px;
	}

	/* tour */
	body .section-tour-inner {
		padding: 70px 0;
	}
	body .section-tour-title {
		font-size: 50px;
	}

	/* services */
	body .section-services-tabs-nav-item {
		margin-left: 30px;
		margin-right: 30px;
	}

	/* process */
	body .section-process {
		padding: 90px 0;
	}

	/* team */
	body .section-header-left {
		margin-right: 0;
		float: none;
	}
	body .section-header-right {
		overflow: visible;
		padding-left: 0;
		float: none;
		border: 0;
	}
	body .section-header-right.has-button .section-description {
		overflow: visible;
		float: none;
		margin-top: 30px;
	}
	body .section-header-button {
		margin-left: 0;
		float: none;
		line-height: 38px;
    	width: auto;
    	display: inline-block;
	}
	body .section-team-items .widget {
		margin-bottom: 50px;
	}
	body .section-team-items .widget:last-child {
		margin-bottom: 0;
	}

	/* blog */
	body .section-blog-info {
		width: 100%;
		margin-bottom: 40px;
		position: relative;
	}
	body .section-blog-items {
		width: 100%;
	}
	body .section-blog-filters {
		margin-bottom: 0;
	}
	body .section-blog-filters li {
		display: inline-block;
		margin-right: 20px;
		margin-bottom: 0;
	}
	body .section-blog-button {
		position: absolute;
		top: 0;
		right: 0;
	}

	/* contact */
	body .section-contact-form {
		padding: 30px;
	}
	body .section-contact-form .section-subtitle {
		margin-bottom: 30px;
	}
	body .section-contact-extra-item-icon {
		width: 40px;
		height: 40px;
		line-height: 40px;
		font-size: 12px;
		margin-right: 15px;
	}
	body .section-contact-extra-item-main strong {
		margin-top: 0;
		margin-bottom: 10px;
	}

	/**
	 * Post single
	 */

	/* comments */
	body .comment .children {
	 	margin-left: 30px;
	}
	body .comment .children .children .children {
		margin-left: 0;
	}

}

/*--------------------------------------------------------------
	## Phones ( landscape + portrait )
--------------------------------------------------------------*/

@media only screen and ( max-width: 767px ) {

	/* Columns */

	body .col {
		margin-right: 0;
		width: 100% !important;
	}

	/* Header */
	body.page-template-template-home-php.admin-bar #header {
		top: 46px;
	}

	/* Navigation */

	body #navigation {
		display: none;
	}
	body #mobile-navigation {
		display: block;
	}

	/**
	 * Homepage
	 */
	
	/* general */
	body .section {
		padding: 50px 0;
	}
	body .section-header {
		margin-bottom: 50px;
	}
		body .section-subtitle {
			margin-bottom: 15px;
			font-size: 18px;
		}
		body .section-description {
			font-size: 14px;
		}

	/* slider */
	body .slide-info-inner {
		max-width: 100%;
	}
		body .slide-info-title {
			font-size: 25px;
		}
		body .slide-info-content {
			margin-bottom: 15px;
		}
		body .slide-info-button {
			line-height: 38px;
			width: auto;
		}

	/* features */
	body .section-features-main-wrap:before,
	body .section-features-main:before {
		display: none;
	}
	body .section-features-items,
	body .section-features-main-inner {
		padding-top: 0;
	}
		body .section-features-item {
			margin-bottom: 50px;
		}
		body .section-features-image-caption {
			position: relative;
			left: auto;
			right: auto;
			top: auto;
			bottom: auto;
		}

	/* about */
	body .section-about-items .widget {
		margin-bottom: 30px;
		margin-top: 0;
	}
	body .section-about-items .widget:nth-child(2) {
		box-shadow: none;
	}
	body .section-about-items .widget:last-child {
		margin-bottom: 0;
	}
		body .section-about-item {
			padding: 50px 30px;
		}
		body .section-about-item-icon {
			width: 80px;
			line-height: 80px;
			height: 80px;
		}

	/* tour */
	body .section-tour {
		padding: 0;
	}
	body .section-tour-inner {
		padding: 50px 0;
	}
	body .section-tour-title {
		font-size: 25px;
	}

	/* services */
	body .section-services-tabs-nav {
		display: none;
	}
	body .section-services-tabs-content .widget {
		margin-bottom: 50px;
	}
	body .section-services-tabs-content .widget:last-child {
		margin-bottom: 0;
	}
	body .section-services-tabs-content-item {
		display: block !important;
	}
	body .section-services-tabs-content-info {
		position: relative;
		top: auto !important;
		left: auto;
		right: auto;
		bottom: auto;
		padding-bottom: 0 !important;
	}
	body .section-services-tabs-content-info-title {
		font-size: 20px;
		display: block
	}
	body .section-services-tabs-content-info-description {
		max-width: none;
		padding: 20px;
	}

	/* process */
	body .section-process-items .widget {
		margin-bottom: 50px;
		margin-top: 0;
	}
	body .section-process-items .widget:last-child {
		margin-bottom: 0;
	}

	/* testimonials */
	body .section-testimonials-item {
		padding: 0;
	}
	body .section-testimonials-item-thumb {
		float: none;
		margin-bottom: 30px;
	}
	body .section-testimonials .wrapper {
		max-width: 100%;
	}
	body .section-testimonials-customer-count-inner {
		padding: 20px;
	}
	body .section-testimonials-customer-count span {
		font-size: 40px;
		margin-right: 20px;
	}
	.section-testimonials-customer-count strong {
		font-size: 14px;
	}

	/* team */
	body .section-header-left {
		margin-right: 0;
		float: none;
	}
	body .section-header-right {
		overflow: visible;
		padding-left: 0;
		float: none;
		border: 0;
	}
	body .section-header-right.has-button .section-description {
		overflow: visible;
		float: none;
		margin-top: 30px;
	}
	body .section-header-button {
		margin-left: 0;
		float: none;
		line-height: 38px;
    	width: auto;
    	display: inline-block;
	}
	body .section-team-items .widget {
		margin-bottom: 50px;
		margin-top: 0;
	}
	body .section-team-items .widget:last-child {
		margin-bottom: 0;
	}

	/* blog */
	body .section-blog-filters {
		display: none;
	}
	body .section-blog-button {
		line-height: 38px;
    	width: auto;
    	display: inline-block;
	}
	body .section-blog-info {
		margin-bottom: 40px;
	}
	body .section-blog-item {
		margin-bottom: 40px;
	}
	body .section-blog-item:last-child {
		margin-bottom: 0;
	}

	/* contact */
	body .section-contact-form {
		padding: 30px;
	}
	body .section-contact-form .section-subtitle {
		margin-bottom: 30px;
	}
	body .section-contact-extra-item-icon {
		display: none;
	}
	body .section-contact-extra .widget {
		margin-bottom: 40px;
		margin-top: 0;
	}
	body .section-contact-extra .widget:last-child {
		margin-bottom: 0;
	}
	body .section-contact-extra {
		margin-top: 40px;
	}

	/**
	 * Content
	 */

	body #content.col {
		margin-bottom: 50px;
	}

	body .comment .children {
		margin-left: 0;
	}

	/* footer */
	body .footer-subscribe{
		padding: 50px 0;
	}
	body .footer-subscribe-content {
		margin-bottom: 40px;
	}

	body #footer-social,
	body #footer-copyright {
		float: none;
		text-align: center;
	}

	body #footer-copyright {
		margin-bottom: 15px;
	}

	body #footer .widget {
		margin: 0;
		margin-bottom: 40px;
	}

	body #footer .widget:last-child {
		margin-bottom: 0;
	}

}

/*--------------------------------------------------------------
	## Phones ( landscape )
--------------------------------------------------------------*/

@media only screen and ( min-width: 480px ) and ( max-width: 767px ) {

	body .wrapper {
		max-width: 420px;
	}

	body .header-search form {
		width: 420px;
	}

}

/*--------------------------------------------------------------
	## Phones ( portrait )
--------------------------------------------------------------*/

@media only screen and ( max-width: 479px ) {

	body .wrapper {
		max-width: 300px;
	}

	body .header-search form {
		width: 300px;
	}

	/**
	 * Homepage
	 */

	/* slider */
	body .slide-info .wrapper {
		width: 100%;
		max-width: 100%;
		padding: 0 20px;
	}
		body .slide-info-title {
			font-size: 20px;
		}
		body .slide-info-content {
			display: none;
		}	

	/**
	 * Listing
	 */

	body.blog #main .wrapper,
	body.archive #main .wrapper,
	body.search-results #main .wrapper,
	body.page-template-default #main .wrapper,
	body.error404 #main .wrapper,
	body.single-post #main .wrapper {
		max-width: 100%;
		padding: 0 20px;
	}
	
	/* Footer */

	body #footer-navigation li {
		margin-left: 10px;
	}

}