<div id="footer-bottom">

	<div class="wrapper clearfix">

		<div id="footer-copyright">
			<?php printf( esc_html__( 'Theme: %1$s by %2$s', 'meridian-one' ), 'Meridian One', '<a href="https://meridianthemes.net">MeridianThemes.net</a>' ); ?>
		</div><!-- #footer-copyright -->

		<div id="footer-social">
			<?php if ( meridian_one_get_theme_option( 'social_twitter' ) ) : ?>
				<a class="social-link-twitter" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_twitter' ) ); ?>" target="_blank"><span class="fa fa-twitter"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_facebook' ) ) : ?>
				<a class="social-link-facebook" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_facebook' ) ); ?>" target="_blank"><span class="fa fa-facebook"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_youtube' ) ) : ?>
				<a class="social-link-youtube" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_youtube' ) ); ?>" target="_blank"><span class="fa fa-youtube-play"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_vimeo' ) ) : ?>
				<a class="social-link-vimeo" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_vimeo' ) ); ?>" target="_blank"><span class="fa fa-vimeo"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_tumblr' ) ) : ?>
				<a class="social-link-tumblr" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_tumblr' ) ); ?>" target="_blank"><span class="fa fa-tumblr"></span></a>					
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_pinterest' ) ) : ?>
				<a class="social-link-pinterest" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_pinterest' ) ); ?>" target="_blank"><span class="fa fa-pinterest"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_linkedin' ) ) : ?>
				<a class="social-link-linkedin" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_linkedin' ) ); ?>" target="_blank"><span class="fa fa-linkedin"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_instagram' ) ) : ?>
				<a class="social-link-instagram" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_instagram' ) ); ?>" target="_blank"><span class="fa fa-instagram"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_github' ) ) : ?>
				<a class="social-link-github" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_github' ) ); ?>" target="_blank"><span class="fa fa-github"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_googleplus' ) ) : ?>
				<a class="social-link-googleplus" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_googleplus' ) ); ?>" target="_blank"><span class="fa fa-googleplus"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_dribbble' ) ) : ?>
				<a class="social-link-dribbble" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_dribbble' ) ); ?>" target="_blank"><span class="fa fa-dribbble"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_dropbox' ) ) : ?>
				<a class="social-link-dropbox" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_dropbox' ) ); ?>" target="_blank"><span class="fa fa-dropbox"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_flickr' ) ) : ?>
				<a class="social-link-flickr" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_flickr' ) ); ?>" target="_blank"><span class="fa fa-flickr"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_foursquare' ) ) : ?>
				<a class="social-link-foursquare" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_foursquare' ) ); ?>" target="_blank"><span class="fa fa-foursquare"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_behance' ) ) : ?>
				<a class="social-link-behance" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_behance' ) ); ?>" target="_blank"><span class="fa fa-behance"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_vine' ) ) : ?>
				<a class="social-link-vine" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_vine' ) ); ?>" target="_blank"><span class="fa fa-vine"></span></a>
			<?php endif; ?>
			<?php if ( meridian_one_get_theme_option( 'social_rss' ) ) : ?>
				<a class="social-link-rss" href="<?php echo esc_url( meridian_one_get_theme_option( 'social_rss' ) ); ?>" target="_blank"><span class="fa fa-rss"></span></a>
			<?php endif; ?>
		</div><!-- #footer-navigation -->

	</div><!-- .wrapper -->

</div><!-- #footer-bottom -->