<?php
/**
 * The template part for displaying the services section on homepage
 *
 * @package Meridian One
 * @since 1.0
 */
?>
<?php

	$title = false;
	$subtitle = false;
	$description = false;

	if ( meridian_one_get_theme_option( 'home_services_section_title' ) ) {
		$title = meridian_one_get_theme_option( 'home_services_section_title' );
	}

	if ( meridian_one_get_theme_option( 'home_services_section_subtitle' ) ) {
		$subtitle = meridian_one_get_theme_option( 'home_services_section_subtitle' );
	}

	if ( meridian_one_get_theme_option( 'home_services_section_description' ) ) {
		$description = meridian_one_get_theme_option( 'home_services_section_description' );
	}

?>
<div id="services" class="section section-services">

	<div class="wrapper">

		<?php if ( $title || $subtitle || $description ) : ?>
			<div class="section-header">
				<?php if ( $title ) : ?>
					<h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
				<?php endif; ?>
				<?php if ( $subtitle ) : ?>
					<h3 class="section-subtitle"><?php echo esc_html( $subtitle ); ?></h3>
				<?php endif; ?>
				<?php if ( $description ) : ?>
					<div class="section-description"><?php echo esc_html( $description ); ?></div>
				<?php endif; ?>
			</div><!-- .section-header -->
		<?php endif; ?>

		<div class="section-services-main">

			<div class="section-services-tabs-nav"></div>

			<?php if ( is_active_sidebar( 'sidebar-home-services' ) ) : ?>
				<div class="section-services-tabs-content">
					<?php dynamic_sidebar( 'sidebar-home-services' ); ?>
				</div><!-- .section-services-tabs-content -->
			<?php endif; ?>

		</div><!-- .section-services-main -->

	</div><!-- .wrapper -->

</div><!-- .section-services -->