/*--------------------------------------------------
	MAIN
---------------------------------------------------*/
.clear {clear:both;}
/*--------------------------------------------------
	FORMS
---------------------------------------------------*/
.optinforms-confirm-checkbox { font-size: 12px; text-align: left; margin-top: 10px; }

#optinforms-form1-container {width: 100%; margin: 10px auto 20px auto;}
#optinforms-form1 {display: block; float: left; width: 100%; background:#efefef; padding: 15px 3%; text-align: center; margin: 0 0 5px; border-radius: 8px; border: 2px solid #e0e0e0; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
/* on admin pages */
#optinforms-form1-title {display: block; text-align: center; color: #eb432c; margin: 0 0 15px; font-family: Damion, sans-serif;}
#optinforms-form1-subtitle {font-size: 16px; color: #333; margin: 20px 0;}
#optinforms-form1-name-field-container, #optinforms-form1-email-field-container {display: inline; float: left; width: 38%; margin: 0 2% 0 0;}
#optinforms-form1-button-container {display: inline; float: left; width: 20%; margin: 0;}
#optinforms-form1-name-field {color: #666; padding: 8px 8px 8px 33px!important; background: url(../images/icon-user-01.png) no-repeat left center #fff; width: 100%; border:1px solid #DFDFDF; border-radius: 4px; -webkit-transition: all .2s ease-out; -moz-transition: all .2s ease-out; -ms-transition: all .2s ease-out;transition: all .2s ease-out; box-shadow: none; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form1-email-field {color: #666; padding: 8px 8px 8px 33px!important; background: url(../images/icon-email-01.png) no-repeat left center #fff; width: 100%; border:1px solid #DFDFDF; border-radius: 4px; -webkit-transition: all .2s ease-out; -moz-transition: all .2s ease-out; -ms-transition: all .2s ease-out;transition: all .2s ease-out; box-shadow: none; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form1-button {margin: 2px 0 0; color: #fff; background: #20a64c; padding: 6px; border: 0; border-radius: 4px; font-size: 14px; font-weight: 700; cursor: pointer; width:100%; text-shadow: none;}
#optinforms-form1-disclaimer {font-size: 11px; color: #666; margin:10px 0;}
#optinforms-form1 .optinforms-confirm-checkbox { text-align: center; }

#optinforms-form2-container {width: 100%; margin: 10px auto 20px auto;}
#optinforms-form2 {display: block; float: left; width: 100%; background: #266d7c; padding: 15px 3%; text-align: center; margin: 0 0 5px; border-radius: 8px; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form2-title-container {display: inline; float: left; width: 30%; text-align: left; margin: 0 2% 0 0;}
#optinforms-form2-title {color: #fff; font-family: Pacifico, sans-serif; font-size: 30px; line-height: 30px;}
#optinforms-form2-email-field-container {display: inline; float: left; width: 30%; text-align: left;}
#optinforms-form2-email-field {color: #000; padding: 8px 8px 8px 33px; background: url(../images/icon-email-01.png) no-repeat left center #fff; width:100%; border:1px solid #DFDFDF; border-radius: 4px; -webkit-transition: all .2s ease-out; -moz-transition: all .2s ease-out; -ms-transition: all .2s ease-out;transition: all .2s ease-out; box-shadow: none; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form2-button-container {display: inline; float: left; width: 18%; text-align: left; margin: 0 0 0 2%;}
#optinforms-form2-button {margin: 2px 0 0; color: #fff; background: #49A3FE; padding: 6px; border: 0; border-radius: 4px; font-size: 14px; font-weight: 700; cursor: pointer; width:100%; text-shadow: none;}
#optinforms-form2-disclaimer-container {display: inline; float: left; width: 16%; text-align: left; margin: 0 0 0 2%;}
#optinforms-form2-disclaimer {font-size: 11px; color: #fff; margin: 12px 0;}
#optinforms-form2 .optinforms-confirm-checkbox { color: #fff; }
#optinforms-form2 .optinforms-confirm-checkbox a { color: inherit; }

#optinforms-form3-container {width: 100%; margin: 10px auto 20px auto;}
#optinforms-form3 {display: block; float: left; width: 100%; background: url(../images/form3-border-top.gif) repeat-x #fff; padding: 0; text-align: center; margin: 0 0 5px; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form3-inside {display: block; width: 100%; padding: 15px 3%; background: #f0f0f0; margin: 12px 0 0; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form3-container-left {display: inline; float: left; width: 58%; margin: 10px 1% 0 0; text-align: left;}
#optinforms-form3-container-right {display: inline; float: left; width: 38%; margin: 10px 0 0 1%; text-align: left;}
#optinforms-form3-title {color: #505050; font-family: Droid Serif, sans-serif; font-size: 30px; line-height: 30px;}
#optinforms-form3-subtitle {font-size: 16px; color: #505050; margin: 20px 10px 20px 0; line-height: 28px;}
#optinforms-form3-name-field {color: #666; padding: 8px 8px 8px 33px; margin: 0 0 5px 0; background: url(../images/icon-user-01.png) no-repeat left center #fff; width:100%; border:1px solid #DFDFDF; border-radius: 4px; -webkit-transition: all .2s ease-out; -moz-transition: all .2s ease-out; -ms-transition: all .2s ease-out;transition: all .2s ease-out; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form3-email-field {color: #666; padding: 8px 8px 8px 33px; margin: 0 0 5px 0;  background: url(../images/icon-email-01.png) no-repeat left center #fff; width:100%; border:1px solid #DFDFDF; border-radius: 4px; -webkit-transition: all .2s ease-out; -moz-transition: all .2s ease-out; -ms-transition: all .2s ease-out;transition: all .2s ease-out; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form3-button {margin: 0; color: #fff; background: #49A3FE; padding: 6px; border: 0; border-radius: 4px; font-size: 18px; font-weight: 700; cursor: pointer; width:100%; text-shadow: none;}
#optinforms-form3 .optinforms-confirm-checkbox { margin-bottom: 10px; }

#optinforms-form4-container {width: 100%; margin: 10px auto 20px auto;}
#optinforms-form4 {display: block; float: left; width: 100%; background: #FCFCFC; padding: 15px 3%; text-align: center; margin: 0 0 5px; border: 2px solid #ECEAED; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form4-title {color: #505050; font-family: Arial, sans-serif; font-size: 24px; line-height: 24px; margin: 10px 0;}
#optinforms-form4-subtitle {font-size: 16px; color: #505050; margin: 15px 0; line-height: 28px;}
#optinforms-form4-email-field {color: #666; padding: 8px; margin: 0 0 5px 0;  background: #fff; width:100%; text-align: center; font-size: 16px; border:1px solid #DFDFDF; border-radius: 4px; -webkit-transition: all .2s ease-out; -moz-transition: all .2s ease-out; -ms-transition: all .2s ease-out;transition: all .2s ease-out; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form4-button {margin: 0; color: #1d629b; background: #faff5b; padding: 6px; border: 0; border-radius: 4px; font-size: 20px; font-weight: 700; cursor: pointer; width:100%; text-shadow: none;}
#optinforms-form4-disclaimer {font-size: 12px; color: #999; margin:10px 0;}
#optinforms-form4 .optinforms-confirm-checkbox { text-align: center; margin-bottom: 10px; }

#optinforms-form5-container {width: 100%; margin: 10px auto 20px auto;}
#optinforms-form5 {display: block; float: left; width: 100%; background: #333333; padding: 15px 3%; text-align: center; margin: 0 0 5px; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form5-container-left {display: inline; float: left; width: 39%; margin: 10px 1% 10px 0; text-align: left;}
#optinforms-form5-container-right {display: inline; float: left; width: 59%; margin: 10px 0 10px 1%; text-align: left;}
#optinforms-form5-title {color: #fb6a13; font-family: "News Cycle", sans-serif; font-size: 28px; line-height: 28px; margin: 0 0 20px 0;}
#optinforms-form5-subtitle {font-size: 16px; line-height: 26px; font-family: Georgia, "Times New Roman", Times, serif; color: #ccc; margin: 0 20px;}
#optinforms-form5-name-field {color: #000; padding: 8px 8px 8px 33px; margin: 0 0 10px 0; background: url(../images/icon-user-01.png) no-repeat left center #fff; width:100%; border: 1px solid #DFDFDF; border-radius: 4px; -webkit-transition: all .2s ease-out; -moz-transition: all .2s ease-out; -ms-transition: all .2s ease-out;transition: all .2s ease-out; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form5-email-field {color: #000; padding: 8px 8px 8px 33px; margin: 0 0 10px 0;  background: url(../images/icon-email-01.png) no-repeat left center #fff; width:100%; border: 1px solid #DFDFDF; border-radius: 4px; -webkit-transition: all .2s ease-out; -moz-transition: all .2s ease-out; -ms-transition: all .2s ease-out;transition: all .2s ease-out; -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */ -moz-box-sizing: border-box; /* Firefox, other Gecko */ box-sizing: border-box;}
#optinforms-form5-button {margin: 0; color: #fff; background: #fb6a13; padding: 6px; border: 0; border-radius: 4px; font-size: 16px; font-weight: 700; cursor: pointer; width:100%;}
#optinforms-form5-disclaimer {font-size: 14px; line-height: 26px; font-family: Georgia, "Times New Roman", Times, serif; color: #727272; margin: 20px 20px 0 20px;}
#optinforms-form5 .optinforms-confirm-checkbox { color: #727272; }
#optinforms-form5 .optinforms-confirm-checkbox a { color: inherit; }

#optinforms-powered-by {width: 99%; text-align: right; font-size: 11px; color: #666; margin: 10px 1% 0 0;}
.sticky-placeholder-wrapper > label {opacity:.5; -webkit-transition: opacity .2s ease-out; -moz-transition: opacity .2s ease-out; -ms-transition: opacity .2s ease-out; transition: opacity .2s ease-out;}

/*--------------------------------------------------
	MEDIA
---------------------------------------------------*/
@media only screen and (min-width: 768px) and (max-width: 959px) {
#optinforms-form1-name-field-container, #optinforms-form1-email-field-container{display:block;float:none;width:100%;margin:0 0 5px;} 
#optinforms-form1-name-field,#optinforms-form1-email-field{background:#fff;text-align:center;padding:8px!important;}
#optinforms-form1-button-container{display:block;float:none;width:100%;}

#optinforms-form2-title-container {display:block;width:100%;margin:0 0 10px;}
#optinforms-form2-title{text-align:center;}
#optinforms-form2-email-field-container {display:block;width:100%!important;}
#optinforms-form2-email-field{background:#fff;text-align:center;}
#optinforms-form2-button-container {display:block;width:100%;margin:0;}
#optinforms-form2-disclaimer-container {width:100%;margin:0;}
#optinforms-form2-disclaimer{margin:10px 0 0;text-align:center;}

#optinforms-form3-container-left,#optinforms-form3-container-right{display:block;width:100%;}

#optinforms-form5-container-left,#optinforms-form5-container-right{display:block;width:100%;}
#optinforms-form5-title{text-align:center;}
#optinforms-form5-name-field,#optinforms-form5-email-field{background:#fff;text-align:center;padding:8px!important;}
#optinforms-form5-subtitle, #optinforms-form5-disclaimer{text-align:center;}
}
@media only screen and (min-width: 480px) and (max-width: 767px) {
#optinforms-form1-name-field-container, #optinforms-form1-email-field-container{display:block;float:none;width:100%;margin:0 0 5px;} 
#optinforms-form1-name-field,#optinforms-form1-email-field{background:#fff;text-align:center;padding:8px!important;}
#optinforms-form1-button-container{display:block;float:none;width:100%;}

#optinforms-form2-title-container {display:block;width:100%;margin:0 0 10px;}
#optinforms-form2-title{text-align:center;}
#optinforms-form2-email-field-container {display:block;width:100%!important;}
#optinforms-form2-email-field{background:#fff;text-align:center;}
#optinforms-form2-button-container {display:block;width:100%;margin:0;}
#optinforms-form2-disclaimer-container {width:100%;margin:0;}
#optinforms-form2-disclaimer{margin:10px 0 0;text-align:center;}

#optinforms-form3-container-left,#optinforms-form3-container-right{display:block;width:100%;}

#optinforms-form5-container-left,#optinforms-form5-container-right{display:block;width:100%;}
#optinforms-form5-title{text-align:center;}
#optinforms-form5-name-field,#optinforms-form5-email-field{background:#fff;text-align:center;padding:8px!important;}
#optinforms-form5-subtitle, #optinforms-form5-disclaimer{text-align:center;}
}
@media only screen and (min-width: 320px) and (max-width: 479px) {
#optinforms-form1-name-field-container, #optinforms-form1-email-field-container{display:block;float:none;width:100%;margin:0 0 5px;} 
#optinforms-form1-name-field,#optinforms-form1-email-field{background:#fff;text-align:center;padding:8px!important;}
#optinforms-form1-button-container{display:block;float:none;width:100%;}

#optinforms-form2-title-container {display:block;width:100%;margin:0 0 10px;}
#optinforms-form2-title{text-align:center;}
#optinforms-form2-email-field-container {display:block;width:100%!important;}
#optinforms-form2-email-field{background:#fff;text-align:center;}
#optinforms-form2-button-container {display:block;width:100%;margin:0;}
#optinforms-form2-disclaimer-container {width:100%;margin:0;}
#optinforms-form2-disclaimer{margin:10px 0 0;text-align:center;}

#optinforms-form3-container-left,#optinforms-form3-container-right{display:block;width:100%;}

#optinforms-form5-container-left,#optinforms-form5-container-right{display:block;width:100%;}
#optinforms-form5-title{text-align:center;}
#optinforms-form5-name-field,#optinforms-form5-email-field{background:#fff;text-align:center;padding:8px!important;}
#optinforms-form5-subtitle, #optinforms-form5-disclaimer{text-align:center;}
}