/*--------------------------------------------------------------
	## Typography
--------------------------------------------------------------*/

body {
	max-width: 690px;
}

body,
button,
input,
select,
textarea {
	color: #6b6b6b;
	font-size: 15px;
	font-weight: 400;
	font-family: "Lora", serif;
	line-height: 1.8;
}

h1, h2, h3, h4, h5, h6 {
	clear: both;
	margin: 0;
	padding: 0;
	margin-bottom: 25px;
	color: #343338;
	line-height: 1.45;
	font-weight: normal;
	font-family: "Montserrat";
}

h1 {
	font-size: 33px;
}

h2 {
	font-size: 25px;
}

h3 {
	font-size: 23px;
}

h4 {
	font-size: 21px;
}

h5 {
	font-size: 19px;
}

h6 {
	font-size: 17px;
}

p {
	margin: 0;
	margin-bottom: 25px;
}

p:last-child {
	margin: 0;
}

dfn, cite, em, i {
	font-style: italic;
}

blockquote {
	color: #767676;
	font-size: 17px;
	font-style: italic;
	line-height: 1.8;
	padding: 30px;
	border-left: 2px solid #3db8db;
	background: #edf4f6;
	margin-left: 0;
	margin-right: 0;
}

	blockquote p:last-child {
		margin: 0;
	}

address {
	margin-bottom: 25px
}

pre {
	background: #eee;
	font-family: "Courier 10 Pitch", Courier, monospace;
	font-size: 15px;
	line-height: 1.6;
	margin-bottom: 25px;
	max-width: 100%;
	overflow: auto;
	padding: 1.6em;
}

code, kbd, tt, var {
	font-family: Monaco, Consolas, "Andale Mono", "DejaVu Sans Mono", monospace;
	font-size: 15px;
}

abbr, acronym {
	border-bottom: 1px dotted #666;
	cursor: help;
}

mark, ins {
	background: #fff9c0;
	text-decoration: none;
}

big {
	font-size: 125%;
}

small {
	font-size: 75%;
}

hr {
	background-color: #ccc;
	border: 0;
	height: 1px;
	margin-bottom: 25px;
}

ul,
ol {
	margin: 0;
	margin-bottom: 25px;
	padding: 0 0 0 15px;
}

ul {
	list-style: disc;
}

ol {
	list-style: decimal;
}

li > ul,
li > ol {
	margin-bottom: 0;
	margin-left: 0;
}

dt {
	font-weight: bold;
}

dd {
	margin: 0 1.5em 1.5em;
}

img {
	height: auto;
	max-width: 100%;
}

table {
	margin-bottom: 25px;
	width: 100%;
	line-height: 1;
}

table thead {
	background: #2c2c2e;
	color: #fff;
	text-align: left;
}

table td,
table th {
	padding: 10px 14px;
	text-align: left;
}

table tbody th {
	background: #2c2c2e;
	color: #fff;
}

table tbody th a {
	color: inherit;
}

/*--------------------------------------------------------------
	## Links
--------------------------------------------------------------*/

a {
	text-decoration: none;
	color: #3db8db;
}

/*--------------------------------------------------------------
	# WordPress Specific
--------------------------------------------------------------*/

.sticky {
	border: 2px solid #3db8db;
}

.bypostauthor {

}

.alignleft {
	display: inline;
	float: left;
	margin-right: 1.5em;
}

.alignright {
	display: inline;
	float: right;
	margin-left: 1.5em;
}

.aligncenter {
	clear: both;
	display: block;
	margin-left: auto;
	margin-right: auto;
}

/*--------------------------------------------------------------
	## Captions
--------------------------------------------------------------*/

.wp-caption {
	margin: 0;
	margin-top: 20px;
	margin-bottom: 20px;
	max-width: 100%;
}

.wp-caption.alignleft {
	margin-right: 20px;
}

.wp-caption.alignright {
	margin-left: 20px;
}

.wp-caption img[class*="wp-image-"] {
	display: block;
	margin-left: auto;
	margin-right: auto;
	-moz-box-shadow: 0px 0px 5px 0px rgba( 0, 0, 0, 0.15 );
	-webkit-box-shadow: 0px 0px 5px 0px rgba( 0, 0, 0, 0.15 );
	box-shadow: 0px 0px 5px 0px rgba( 0, 0, 0, 0.15 );
}

.wp-caption .wp-caption-text {
	font-size: 14px;
	line-height: 1.7;
	margin: 0;
	padding: 0 10%;
	font-family: "Lato", sans-serif;
	margin-top: 20px;
}

.wp-caption-text {
	text-align: center;
}

/*--------------------------------------------------------------
	## Galleries
--------------------------------------------------------------*/

.gallery {
	margin-bottom: 1.5em;
}

.gallery-item {
	display: inline-block;
	text-align: center;
	vertical-align: top;
	width: 100%;
	padding: 5px;
}

.gallery-item a,
.gallery-item img {
	display: block;
}

.gallery-columns-2 .gallery-item {
	max-width: 50%;
}

.gallery-columns-3 .gallery-item {
	max-width: 33.33%;
}

.gallery-columns-4 .gallery-item {
	max-width: 25%;
}

.gallery-columns-5 .gallery-item {
	max-width: 20%;
}

.gallery-columns-6 .gallery-item {
	max-width: 16.66%;
}

.gallery-columns-7 .gallery-item {
	max-width: 14.28%;
}

.gallery-columns-8 .gallery-item {
	max-width: 12.5%;
}

.gallery-columns-9 .gallery-item {
	max-width: 11.11%;
}

.gallery-caption {
	display: block;
}

