<?php
/**
 * The template part for displaying the primary navigation
 *
 * @package Meridian One
 * @since 1.0
 */
?>
<?php if ( has_nav_menu( 'menu-1' ) ) : ?>

	<nav id="navigation">
		<?php wp_nav_menu( array( 'theme_location' => 'menu-1', 'menu_id' => 'primary-menu', 'fallback_cb' => false ) ); ?>
	</nav><!-- #navigation -->

	<div id="mobile-navigation">
		<div class="header-mobile-nav-hook">
			<span class="fa fa-reorder"></span><?php esc_html_e( 'Navigation', 'meridian-one' ); ?>
			<div id="mobile-navigation-menu">
				<div class="wrapper"><?php wp_nav_menu( array( 'theme_location' => 'menu-1', 'menu_id' => 'primary-menu-mobile', 'fallback_cb' => false ) ); ?></div>
			</div><!-- #mobile-navigation-menu -->
		</div><!-- .header-mobile-nav-hook -->
	</div><!-- #mobile-navigation -->

<?php endif; ?>