.alignfull{
    margin-left: calc(50% - 50vw);
    margin-right: calc(50% - 50vw);
    width: auto;
    max-width: 1000%;
}
.wp-block-button__link{
  background-color:#000;
}
.wp-block-image img {
  display: block;
}

.wp-block-image.alignleft,
.wp-block-image.alignright {
  width: 100%
}

.wp-block-image.alignfull img {
  width: 100vw;
}

.wp-block-gallery:not(.components-placeholder) {
  margin: 1.5em auto;
}

.wp-block-cover-text p {
  padding: 1.5em 14px;
}
ul.wp-block-gallery.alignleft.columns-2.is-cropped {
    margin-right: 2em/*!rtl:end:ignore; */;
}
ul.wp-block-gallery.alignwide {
    width: 100%;
    overflow: hidden;
    clear: both;
}
.wp-block-quote.is-large, .wp-block-quote.is-style-large {
    margin: 0 0 16px;
   padding: 30px 50px 30px 80px;
}
.is-style-solid-color blockquote {
    background: transparent;
}
ul.wp-block-latest-posts.alignwide,
ul.wp-block-latest-posts.alignfull,
ul.wp-block-latest-posts.is-grid.alignwide,
ul.wp-block-latest-posts.is-grid.alignwide {
  padding: 0 14px;
}

.wp-block-table {
  display: block;
  overflow-x: auto;
}

.wp-block-table table {
  border-collapse: collapse;
  width: 100%
}

.wp-block-table td, .wp-block-table th {
  padding: .5em;
}

.wp-block-embed.type-video > .wp-block-embed__wrapper {
  position: relative;
  width: 100%;
  height: 0;
  padding-top: 56.25%;
}

.wp-block-embed.type-video > .wp-block-embed__wrapper > iframe {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
}

.wp-block-quote.is-large {
  margin: 0 auto 16px;
}

.wp-block-pullquote>p:first-child {
  margin-top: 0;
}

.wp-block-separator {
  margin: 3em auto;
  padding: 0;
}
/*embide style*/
.alignwide.wp-block-embed,
.alignfull.wp-block-embed {
	position: relative;
	padding-bottom: 56.25%; /* 16:9 */
	padding-top: 25px;
	height: 0;
}
.alignwide.wp-block-embed iframe,
.alignfull.wp-block-embed iframe {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
}
.alignwide.wp-block-embed figcaption,
.alignfull.wp-block-embed figcaption{
	bottom:-10px;
	left:0;
	right:0;
	margin-left:auto;
	margin-right:auto;
	position:absolute
}

@media screen and (min-width: 768px) {
  .wp-block-cover-text p {
    padding: 1.5em 0;
  }

}

/*--------------------------------------------------------------
# Block Color Palette Colors
--------------------------------------------------------------*/
.has-strong-blue-color {
  color: #0073aa;
}

.has-strong-blue-background-color {
  background-color: #0073aa;
}

.has-lighter-blue-color {
  color: #229fd8;
}

.has-lighter-blue-background-color {
  background-color: #229fd8;
}

.has-very-light-gray-color {
  color: #eee;
}

.has-very-light-gray-background-color {
  background-color: #eee;
}

.has-very-dark-gray-color {
  color: #444;
}

.has-very-dark-gray-background-color {
  background-color: #444;
}

/*Default blog some style*/

/*Column bloc */
.wp-block-column{
  margin-bottom: 1.6em;
}

/*block button*/
.wp-block-button__link {
    border-radius: 22px;
    padding: 10px 20px;
    font-size: 16px;
}
.is-style-squared .wp-block-button__link {
    border-radius: 5px;
}
.is-style-outline .wp-block-button__link {
     border: 1px solid currentcolor;
}

/*Common block style*/
.has-large-font-size {
    line-height: 41px;
}
.wp-block-quote:not(.is-large):not(.is-style-large) {
    border-left: inherit;
    padding: 30px 50px 30px 80px;
}

/*Block column*/

.wp-block-gallery.columns-3 ul li {
    width: 33.33%;
    float: left;
}
.wp-block-gallery.columns-2 ul li {
    width: 50%;
    float: left;
}
.wp-block-gallery.columns-4 ul li {
    width: 25%;
    float: left;
}
.wp-block-gallery.columns-5 ul li {
    width: 20%;
    float: left;
}
.wp-block-gallery.columns-6 ul li {
    width: 16.66%;
    float: left;
}
.wp-block-gallery.columns-7 ul li {
    width: 14.28%;
    float: left;
}
.wp-block-gallery.columns-8 ul li {
    width: 12.5%;
    float: left;
}