<?php
/**
 * The template part for displaying the header logo
 *
 * @package Meridian One
 * @since 1.0
 */
?>
<div id="logo" itemscope itemtype="http://schema.org/Brand">
	<?php meridian_one_the_custom_logo(); ?>
	<?php if ( is_front_page() && is_home() ) : ?>
		<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
	<?php else : ?>
		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
	<?php endif; ?>
	<?php $description = get_bloginfo( 'description', 'display' ); ?>
	<?php if ( $description || is_customize_preview() ) : ?>
		<p class="site-description"><?php echo esc_html( $description ); ?></p>
	<?php endif; ?>
</div><!-- #logo -->