<?php ?>

                <div class="optinforms-ad-product">
                    	<h4><a href="https://optinlock.com/?utm_source=OptinForms&utm_medium=link&utm_campaign=sidebar" target="_blank">Optin Forms Pro</a></h4>
                        <p>We are working on something really cool but it may take a few weeks. Signup below to get notified when we launch. In the meantime if you're looking for a premium list building plugin, check out <a href="https://www.wpkube.com/list-building-wordpress-plugins/?utm_source=OptinForms&utm_medium=button&utm_campaign=sidebar" target="_blank">our in-depth guide</a>.</p>
                        <p>You should also check out our guide on <a href="https://www.wpkube.com/wordpress-landing-page-plugins/" target="_blank" rel="noreferrer nofollow">best landing page plugins</a> and <a href="https://www.wpkube.com/best-wordpress-themes/" target="_blank" rel="noreferrer nofollow">best WordPress themes</a>.</p>
                     
                    	<div class="optinforms-ad-product-button">
                            <p><a href="https://optinlock.com/?utm_source=OptinForms&utm_medium=button&utm_campaign=sidebar" target="_blank">Signup to Get Notified</a></p>
                        </div>
                </div><!--optinforms-ad-product-->
                <div class="optinforms-ad">
                    <ul>
                    	<li><a href="https://wordpress.org/support/plugin/optin-forms" target="_blank"><?php echo __('Get support', 'optin-forms'); ?></a></li>
                        <li><a href="https://wordpress.org/support/view/plugin-reviews/optin-forms" target="_blank"><?php echo __('Rate the plugin on WordPress.org', 'optin-forms'); ?></a></li>
                        <li><a href="https://translate.wordpress.org/projects/wp-plugins/optin-forms" target="_blank"><?php echo __('Translate Optin Forms into your language', 'optin-forms'); ?></a></li>
                        <li><a href="https://www.twitter.com/FancyThemes" target="_blank"><?php echo __('Follow me on Twitter', 'optin-forms'); ?></a></li>
                        <li><a href="https://www.wpkube.com/best-wordpress-hosting/" target="_blank"><?php echo __('WordPress Hosting', 'optin-forms'); ?></a></li>
                    </ul>
                </div><!--optinforms-ad-->
                
<?php ?>